@@ -1,5 +1,8 @@
-/* Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees.
-   See file COPYING. */
+/*
+ * Part of Scheme 48 1.9.  See file COPYING for notices and license.
+ *
+ * Authors: David Frese, Marcus Crestani, Mike Sperber
+ */
 
 #ifndef __S48_GC_GENERATION_GC_H
 #define __S48_GC_GENERATION_GC_H
@@ -29,7 +32,10 @@ s48_address s48_allocate_small(long len_in_bytes);
 s48_address s48_allocate_tracedAgc(long len_in_bytes);
 s48_address s48_allocate_untracedAgc(long len_in_bytes);
 s48_address s48_allocate_weakAgc(long len_in_bytes);
+psbool s48_gc_can_allocate_unmovableP();
+s48_address s48_allocate_traced_unmovableAgc(long len_in_bytes);
 s48_address s48_allocate_untraced_unmovableAgc(long len_in_bytes);
+psbool s48_unmovableP(s48_value stob);
 
 extern void s48_initialize_bibop_heap();
 
@@ -37,7 +43,7 @@ extern void s48_integrate_area(Area* area);
 
 /* only used "internally" */
 
-void s48_internal_trace_locationsB(Area* maybe_area, s48_address start,
+void s48_internal_trace_locationsB(Area* maybe_area, char area_looked_up, s48_address start,
 				   s48_address end, char* called_from);
 extern void s48_walk_heap(void (*do_part)(s48_address, s48_address));
 
