@@ -1,5 +1,8 @@
-/* Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees.
-   See file COPYING. */
+/*
+ * Part of Scheme 48 1.9.  See file COPYING for notices and license.
+ *
+ * Authors: David Frese, Mike Sperber
+ */
 
 #ifndef __S48_BIBOP_UTILS_H
 #define __S48_BIBOP_UTILS_H
@@ -49,6 +52,11 @@ extern void write_line(FILE* f, long num);
 extern void s48_bibop_log(const char* message, ...);
 #endif
 
+/* These functions are too dangerous to have around. The BIBOP GC
+   should not need to do much arithmetic on ints, as all sizes must be
+   stored in longs. */
+
+/*
 inline static int int_min(int a, int b) {
   return (a < b) ? a : b;
 }
@@ -56,6 +64,15 @@ inline static int int_min(int a, int b) {
 inline static int int_max(int a, int b) {
   return (a > b) ? a : b;
 }
+*/
+
+inline static unsigned long ulong_min(unsigned long a, unsigned long b) {
+  return (a < b) ? a : b;
+}
+
+inline static unsigned long ulong_max(unsigned long a, unsigned long b) {
+  return (a > b) ? a : b;
+}
 
 #ifndef FALSE
 #define FALSE (0 == 1)
