@@ -1,5 +1,8 @@
-/* Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees.
-   See file COPYING. */
+/*
+ * Part of Scheme 48 1.9.  See file COPYING for notices and license.
+ *
+ * Authors: Mike Sperber
+ */
 
 /* Implementation of SRFI-22-style script interpreters. */
 
