@@ -1,5 +1,7 @@
-/* Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees.
-   See file COPYING. */
+/* Part of Scheme 48 1.9.  See file COPYING for notices and license.
+ *
+ * Authors: Mike Sperber, Robert Ransom
+ */
 
 #define _WIN32_WINNT 0x0400/* for SetWaitableTimer */
 
@@ -102,7 +104,7 @@ s48_schedule_alarm_interrupt(long delta)
 }
 
 /* The next two procedures return times in seconds and ticks
-   (also from Lars Bergstrom's version */
+   (also from Lars Bergstrom's version) */
 
 static DWORD startup_real_time_ticks;
 
