@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey.  See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, David Frese, Marcus Crestani, Mike Sperber
 
 (config '(load "../scheme/vm/macro-package-defs.scm"))
 (load-package 'vm-architecture)
@@ -21,7 +23,7 @@
            '(header "#include \"scheme48vm.h\"")
            '(header "#include \"scheme48heap.h\"")
            ;'(copy (heap walk-over-type-in-area))
-	   '(no-copy (gc s48-trace-locations!))
+	   '(no-copy (gc s48-trace-locations! trace-continuation trace-transport-link-cell))
 	   '(no-copy (write-image trace-image-value))
 	   '(copy (string-tables relocate-table))
            '(integrate (real-copy-object s48-trace-locations!)))))
