@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey.  See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Mike Sperber
 
 
 (define-interface utilities-interface
@@ -24,7 +26,6 @@
           vector-replace
           copy-list
           copy-vector
-          symbol-hash
           string-hash
           char->ascii
           object-hash
@@ -33,6 +34,7 @@
           make-xvector xvector-length xvector-ref xvector-set! xvector->vector
 
           (define-subrecord :syntax)
+	  (define-subrecord-type :syntax)
           ;(define-simple-record-type :syntax)
           (define-local-syntax :syntax)
           ))
@@ -67,6 +69,7 @@
 	  variable-generate set-variable-generate!
           erase-variable
           variable-index copy-variable used? unused?
+	  variable-flag-accessor variable-flag-setter variable-flag-remover
           variable-known-value
 	  add-variable-known-value!
 	  remove-variable-known-value!
