@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey.  See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Mike Sperber
 
 ; Pretty-printing the node tree
 
@@ -185,8 +187,7 @@
              ns)))))
 
 (define (simple-call? call)
-  (and (= '1 (call-exits call))
-       (not (lambda-block (call-arg call 0)))))
+  (= '1 (call-exits call)))
 
 (define (let-call? call)
   (calls-this-primop? call 'let))
