@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey.  See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Marcus Crestani
 
 (define (write-c-io-call call port name . args)
   (format port name)
@@ -166,4 +168,12 @@
     (c-value (call-arg call 2) port)
     (writec port #\))))
 
-
+(define-c-generator call-external-value-2 #t
+  (lambda (call port indent)
+    (format port "((long(*)())")
+    (c-value (call-arg call 0) port)
+    (format port ")(")
+    (c-value (call-arg call 1) port)
+    (format port ", ")
+    (c-value (call-arg call 2) port)
+    (writec port #\))))
