@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey.  See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Timo Harter
 
 ; (make-vector size init)
 
@@ -232,25 +234,63 @@
     (generate-c-switch call port indent)))
 
 (define (generate-c-switch call port indent)
-  (let ((size (call-exits call)))
+  (let ((size (call-exits call))
+        (parent-id (lambda-id (node-parent call))))
+    (display "\n#ifdef USE_DIRECT_THREADING\n" port)
+    (write-goto-jump-table call port indent)
+    (indent-to port indent)
+    (format port "goto *Jtable~D[" parent-id)
+    (c-value (call-arg call (+ size 1)) port)
+    (display "];\n#else\n" port)
     (indent-to port indent)
     (display "switch (" port)
     (c-value (call-arg call (+ size 1)) port)
-    (display ") {" port)
+    (display ") {\n#endif\n" port)
     (let ((indent (+ indent 2)))
       (do ((i 0 (+ i 1))
 	   (labels (literal-value (call-arg call size)) (cdr labels)))
 	  ((>= i size))
+  (display "\n#ifdef USE_DIRECT_THREADING" port)
+	(for-each (lambda (l)
+        (format port "\nJlabel~D_~D:" parent-id l))
+		  (car labels))
+  (display "\n#else\n" port)
 	(for-each (lambda (l)
 		    (indent-to port indent)
 		    (format port "case ~D : " l))
 		  (car labels))
+  (display "\n#endif\n" port)
 	(write-c-switch-case (call-arg call i) port indent)))
+    (display "\n#ifndef USE_DIRECT_THREADING\n" port)
     (indent-to port indent)
-    (display "}" port)))
+    (display "}" port)
+    (display "\n#endif\n" port)))
 
 (define (write-c-switch-case node port indent)
+  (indent-to port (+ indent 2))
   (writec port #\{)
   (write-c-block (lambda-body node) port (+ indent 2))
+  (display "\n#ifndef USE_DIRECT_THREADING\n" port)
   (indent-to port (+ indent 2))
-  (display "break;" port))
+  (display "break;\n#endif\n" port))
+
+(define (write-goto-jump-table call port indent)
+  (let ((size (call-exits call))
+        (parent-id (lambda-id (node-parent call))) ; use the id of the parent lambda to identify this computed-goto
+        (max-value 0))                             ; find the highest case value in the computed goto
+    (for-each
+      (lambda (labels)
+        (for-each
+          (lambda (l) (if (> l max-value) (set! max-value l)))
+          labels))
+      (literal-value (call-arg call size)))
+    (indent-to port indent)
+    (format port "static void *Jtable~D[] = { " parent-id)
+    (do ((i 0 (+ i 1))) ((>= i max-value))
+      (format port "&&Jlabel~D_~D, " parent-id i)
+      (if (equal? 0 (modulo i 6)) ; make the output more readable
+        (indent-to port (+ indent 2))))
+    (format port "&&Jlabel~D_~D };" parent-id max-value)))
+    
+    
+  
