@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey.  See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Marcus Crestani
 
 
 ;(define-scheme-primop cast-to-long)
@@ -32,6 +34,7 @@
 (define-scheme-primop error-string type/string)
 
 (define-scheme-primop call-external-value io type/integer)
+(define-scheme-primop call-external-value-2 io type/integer)
 
 (define-nonsimple-scheme-primop read-block io)
 (define-scheme-primop write-block io type/status)
