@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey.  See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Mike Sperber
 
 (define-polymorphic-scheme-primop make-vector allocate
   (lambda (call)
@@ -28,7 +30,7 @@
 
 (define-nonsimple-scheme-primop record-set! write)
 
-(define (simplify-test call)
+(define (simplify-type-case-test call)
   (simplify-args call 0))
 
 ; There should be no discovered calls to TYPE-CASE.
@@ -44,7 +46,7 @@
   #f)
 
 (define-scheme-cond-primop type-case
-  simplify-test
+  simplify-type-case-test
   expand-test
   simplify-type-case?)
 
