@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2005 by Richard Kelsey.  See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Mike Sperber
 
 
 (define-structures ((fact (export *one* fact all)))
@@ -54,7 +56,7 @@
   (files record))
 
 (define-structures ((buffer (export port->stream stream-read-char)))
-  (open prescheme)
+  (open prescheme ps-record-types ps-memory)
   (files buffer))
 
 (define-structures ((values (export test)))
