@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey.  See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Mike Sperber
 
 
 ; Messages
@@ -43,6 +45,7 @@
 (define (table->list table)
   (select-from-table (lambda (x y) #t) table))
 
+; this is exported from `tables', but that's a fairly recent development
 (define (table->entry-list table)
   (let ((res '()))
     (table-walk (lambda  (key entry)
@@ -154,11 +157,6 @@
 		   (loop (cdr list) next)))))
 	copy)))
 
-(define (symbol-hash symbol)
-  (string-hash (symbol->string symbol)))
-
-(define string-hash (structure-ref features string-hash))
-
 (define (object-hash x)
   0)           ; wah!
 
