@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Mike Sperber
 
 
 ; This configuration file provides alternative implementations of the
@@ -9,13 +11,13 @@
   (open scheme))
 
 (define-structure escapes escapes-interface ;cf. alt/low-packages.scm
-  (open scheme-level-2 define-record-types simple-signals)
+  (open scheme-level-2 define-record-types low-exceptions)
   (files (alt escape)))
 
 (define-structures ((low-level low-level-interface)
 		    (source-file-names (export (%file-name% :syntax)))
 		    (structure-refs (export (structure-ref :syntax))))
-  (open scheme-level-2 simple-signals)
+  (open scheme-level-2 low-exceptions)
   (files (alt low)))
 
 (define-structure closures closures-interface
@@ -41,7 +43,7 @@
 	architecture
 	templates
 	closures
-	simple-signals)
+	low-exceptions)
   (files (link data)
 	 (link transport)
 	 (link write-image)))
@@ -51,7 +53,7 @@
 
 ; Same as in rts-packages.scm:
 (define-structure architecture vm-architecture-interface
-  (open scheme-level-1 simple-signals enumerated)
+  (open scheme-level-1 low-exceptions enumerated)
   (files (vm/interp arch)))
 
 (define-structure define-record-types define-record-types-interface
@@ -60,11 +62,11 @@
 
 ; Same as in rts-packages.scm:
 (define-structure enumerated enumerated-interface
-  (open scheme-level-1 simple-signals)
+  (open scheme-level-1 low-exceptions)
   (files (rts defenum scm)))
 
 (define-structure fluids fluids-interface
-  (open scheme-level-1 simple-signals)
+  (open scheme-level-1 low-exceptions)
   (files (alt fluid)))
 
 (define-structures ((scheme-level-2 scheme-level-2-interface)
@@ -80,8 +82,16 @@
   (open scheme-level-1)
   (files (rts util)))
 
+(define-structure syntax-rules-data syntax-rules-data-interface
+  (open scheme-level-1)
+  (files (rts syntax-rules-data)))
+
+(define-structure syntax-rules-apply syntax-rules-apply-interface
+  (open scheme-level-1)
+  (files (rts syntax-rules-apply)))
+
 (define-structure weak weak-interface
-  (open scheme-level-1 simple-signals)
+  (open scheme-level-1 low-exceptions)
   (files (alt weak)
 	 (rts population)))
 
@@ -93,9 +103,8 @@
 ; run-time internals (generally speaking, things not needed by the linker)
 
 ; * = mentioned in more-packages.scm
-;   simple-conditions
+;   conditions
 ;   continuations
-;   display-conditions
 ; * exceptions
 ; * fluids-internal
 ;   methods
