@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 
 ; Stub support for DEFINE-PACKAGE and DEFINE-INTERFACE macros.
@@ -62,7 +64,7 @@
 
 ; Packages are not what they appear to be.
 
-(define (make-a-package opens-thunk accesses-thunk tower
+(define (make-a-package opens-thunk accesses-thunk tower reader
 			file-name clauses name)
   (vector '<a-package>
 	  (delay (opens-thunk))
@@ -126,7 +128,7 @@
   (register-package! package))
 
 (define dummy-package
-  (make-a-package (lambda () '()) (lambda () '()) #f "" '() #f))
+  (make-a-package (lambda () '()) (lambda () '()) #f #f "" '() #f))
 (define dummy-interface
   (make-simple-interface 'dummy-interface '())) 
 	 
@@ -177,7 +179,7 @@
 	 (list->string (map file-name-preferred-case
 			    (string->list (symbol->string x)))))
 	(else
-	 ;; (error "bogus namelist component" x)
+	 ;; (assertion-violation 'namestring-component "bogus namelist component" x)
 	 "bogus namelist component")))
 
 (define file-name-preferred-case char-downcase)
@@ -208,4 +210,6 @@
 
 (define interface-of structure-interface)
 
-(define-reflective-tower-maker list)
+(define-syntactic-tower-maker list)
+(define-reader read)
+
