@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees
 
 
 
@@ -6,22 +8,22 @@
 ; variants that are much better for one reason or another than
 ; the generic versions defined here.
 
-(define-structures ((simple-signals signals-interface)
+(define-structures ((low-exceptions low-exceptions-interface)
 		    (handle (export ignore-errors))
 		    (features features-interface))
   (open scheme-level-2)
   (files features))
 
 (define-structure records records-interface
-  (open scheme-level-2 simple-signals)
+  (open scheme-level-2 problems)
   (files record))
 
 (define-structure ascii (export ascii->char char->ascii)
-  (open scheme-level-2 simple-signals)
+  (open scheme-level-2 problems)
   (files ascii))
 
 (define-structure bitwise bitwise-interface
-  (open scheme-level-2 simple-signals)
+  (open scheme-level-2 problems)
   (files bitwise))
 
 (define-structure code-vectors code-vectors-interface
