@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 
 ; This is file features.scm.
@@ -8,17 +10,34 @@
 ; Assumes Revised^5 Report Scheme, for EVAL and friends.
 
 
-; SIGNALS
+; LOW-EXCEPTIONS
 
-(define (error message . irritants)
-  (display-error-message "Error: " message irritants)
+(define (error who message . irritants)
+  (display-error-message "Error" who message irritants)
   (an-error-occurred-now-what?))
 
-(define (warn message . irritants)
-  (display-error-message "Warning: " message irritants))
+(define (assertion-violation who message . irritants)
+  (display-error-message "Assertion violation" who message irritants)
+  (an-error-occurred-now-what?))
+  (error who message irritants))
 
-(define (display-error-message heading message irritants)
+(define (implementation-restriction-violation who message . irritants)
+  (display-error-message "Assertion violation" who message irritants)
+  (an-error-occurred-now-what?))
+
+(define (warning who message . irritants)
+  (display-error-message "Warning" who message irritants))
+  
+(define (syntax-violation who message form . maybe-subform)
+  (apply display-error-message "Syntax violation" who message form maybe-subform)
+  ''syntax-error)
+
+(define (note who message . irritants)
+  (display-error-message "Note" who message irritants))
+  
+(define (display-error-message heading who message irritants)
   (display heading)
+  (display " [") (display who) (display "]: ")
   (display message)
   (newline)
   (let ((spaces (list->string
@@ -45,7 +64,6 @@
 
 (define (make-immutable! thing) thing)
 (define (immutable? thing) #f)
-(define (unspecific) (if #f #f))
 
 ; BITWISE -- use alt/bitwise.scm (!)
 ; ASCII -- use alt/ascii.scm
