@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Robert Ransom
 
 
 ; This is JAR's define-record-type, which doesn't resemble Richard's.
@@ -14,6 +16,10 @@
 
 (define-syntax define-record-type
   (syntax-rules ()
+    ((define-record-type ?type ; compatibility with SRFI 9
+       (?constructor ?arg ...) . ?more)
+     (define-record-type ?type ?type
+       (?constructor ?arg ...) . ?more))
     ((define-record-type ?id ?type
        (?constructor ?arg ...)
        (?field . ?field-stuff)
