@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 
 ; Portable versions of low-level things that would really like to rely
@@ -10,3 +12,4 @@
 (define maybe-open-input-file open-input-file)
 (define maybe-open-output-file open-output-file)
 
+(define (unspecific) (if #f #f))
