@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 
 ; BUG: (+ (expt 2 28) (expt 2 28)), (* (expt 2 28) 2)
@@ -12,7 +14,7 @@
 
 ; SIGNALS
 
-(define (error message . irritants)
+(define (error who message . irritants)
   (if (symbol? message)
       (apply schemetoc-error message irritants)
       (apply schemetoc-error
@@ -23,9 +25,18 @@
 			 irritants))
 	     irritants)))
 
-(define (warn message . irritants)
+(define (assertion-violation who message . irritants)
+  (apply error who message irritants))
+
+(define (implementation-restriction-violation who message . irritants)
+  (apply error who message irritants))
+
+(define (warning  who message . irritants)
   (display-error-message "Warning: " message irritants))
 
+(define (note who message . irritants)
+  (display-error-message "Note: " message irritants))
+
 (define (display-error-message heading message irritants)
   (display heading)
   (display message)
@@ -38,17 +49,10 @@
 		(newline))
 	      irritants)))
 
-(define (signal type . stuff)
-  (apply warn "condition signalled" type stuff))
-
-(define (syntax-error . rest)		; Must return a valid expression.
-  (apply warn rest)
+(define (syntax-violation who message form . maybe-subform)
+  (apply warning who message form maybe-subform)
   ''syntax-error)
 
-(define (call-error message proc . args)
-  (error message (cons proc args)))
-
-
 ; FEATURES
 
 (define force-output flush-buffer)
