@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; package -> template
 
@@ -56,14 +58,14 @@
 ; forth).  This adds the appropriate transform to ENV.
 
 (define (define-usual-transform env name)
-  (environment-define! env
-		       name
-		       syntax-type
-		       (make-transform (usual-transform name)
-				       (extract-package-from-environment env)
-				       syntax-type
-				       `(usual-transform ',name)
-				       name)))
+  (comp-env-define! env
+		    name
+		    syntax-type
+		    (make-transform/macro (usual-transform name)
+					  (extract-package-from-comp-env env)
+					  syntax-type
+					  `(usual-transform ',name)
+					  name)))
 
 ; This adds definitions of all operators to ENV and returns a list of forms
 ; that define the closed-compiled versions of those operators that have such.
@@ -75,19 +77,14 @@
   (table-walk (lambda (name op)
 		(let ((type (operator-type op)))
 		  (if (not (eq? (operator-type op) 'leaf))
-		      (environment-define! env name (operator-type op) op))))
+		      (comp-env-define! env name (operator-type op) op))))
 	      operators-table)
 
-  (environment-define! env 'all-operators vector-type)
+  (comp-env-define! env 'all-operators vector-type)
   
   (let ((all-operators-node (expand 'all-operators env))
 	(vector-set!-node (make-node operator/literal (get-primop 'vector-set!)))
 	(procs '())
-	(primop-count
-	 (let ((count 0))
-	   (walk-primops (lambda (name type primop)
-			   (set! count (+ 1 count))))
-	   count))
 	(index 0))
 
     (define (make-define-primitive-node name env)
@@ -104,7 +101,7 @@
 			     (expand name env)))))
 
     (walk-primops (lambda (name type primop)
-		    (environment-define! env name type primop)
+		    (comp-env-define! env name type primop)
 		    (set! procs
 			  (cons (make-define-primitive-node name env)
 				(cons
@@ -121,7 +118,7 @@
 			   (cons (make-node operator/literal 
 					    (get-primop 'make-vector))
 				 (list (make-node operator/literal
-						  primop-count))))))
+						  index))))))
 	   procs))
 
     procs))
