@@ -1,5 +1,8 @@
 ; -*- Mode: Scheme; Syntax: Scheme; Package: Scheme; -*-
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, 
+;          Martin Gasbichler, Marcus Crestani, Mike Sperber, Robert Ransom
 
 ; Compiling primitive procedures and calls to them.
 
@@ -15,8 +18,7 @@
 	    (literal->index frame (primop-closed-template name)))
 	  (instruction (enum op push))
 	  (instruction (enum op false))		; no environment
-	  (instruction (enum op make-stored-object) 2 (enum stob closure))
-	  (instruction (enum op make-immutable!)))
+	  (instruction (enum op make-stored-object) 2 (enum stob closure)))
 	cont))))
 
 (define (primop-closed-template name)
@@ -110,10 +112,6 @@
     ((arithmetic-shift)
      ,(proc (exact-integer-type exact-integer-type)
 	    exact-integer-type))
-    ((char=? char<?)
-     ,(proc (char-type char-type) boolean-type))
-    (string=?
-     ,(proc (string-type string-type) boolean-type))
     (open-channel
      ;; Can return #f
      ,(proc (string-type value-type exact-integer-type boolean-type) value-type))
@@ -134,7 +132,7 @@
     ((= opcode op-count))
   (let ((arg-specs (vector-ref opcode-arg-specs opcode))
         (name (enumerand->name opcode op)))
-    (cond ((memq name '(call-external-value
+    (cond ((memq name '(call-external-value call-external-value-2
 			return-from-interrupt return
 			binary-comparison-reduce2)))
           ((null? arg-specs)
@@ -161,7 +159,8 @@
   (let ((winner? (fixed-arity-procedure-type? type)))
     (let ((nargs (if winner?
                      (procedure-type-arity type)
-                     (error "n-ary simple primitive?!" name type))))
+                     (assertion-violation 'define-simple-primitive
+					  "n-ary simple primitive?!" name type))))
       (define-compiler-primitive name type
         (simple-compilator segment)
         (simple-closed-compilator nargs segment)))))
@@ -369,7 +368,7 @@
 
 ; SIGNAL-CONDITION is the same as TRAP.
 
-(define-simple-primitive 'signal-condition (proc (pair-type) unspecific-type)
+(define-simple-primitive 'signal-condition (proc (value-type) unspecific-type)
   (instruction (enum op trap)))
 
 ; (primitive-catch (lambda (cont) ...))
@@ -390,14 +389,14 @@
 			       (+ depth 1)
 			       frame
 			       (fall-through-cont node 1))
-		      (call-instruction 1 label)	; one argument
+		      (call-instruction 1 (+ depth 1) label) ; one argument
 		      after))))
   (lambda (frame)
     (sequentially (lambda-protocol 1 #f #f #f)
                   (instruction (enum op current-cont))
 		  (instruction (enum op push))
 		  (instruction (enum op stack-ref) 1)
-                  (call-instruction 1 #f))))	; one argument, no return label
+                  (call-instruction 1 (+ (frame-size frame) 1) #f)))) ; one argument, no return label
 
 ; (call-with-values producer consumer)
 
@@ -501,8 +500,9 @@
     (let ((exp (node-form node)))
       (if (>= (length (cdr exp)) min-nargs)
           (compilator node depth frame cont)
-          (begin (warn "too few arguments to primitive"
-                       (schemify node))
+          (begin (warning 'n-ary-primitive-compilator
+			  "too few arguments to primitive"
+			  (schemify node))
                  (compile-unknown-call node depth frame cont))))))
 
 ; APPLY wants the arguments on the stack, with the final list on top, and the
@@ -571,7 +571,8 @@
 					       " arguments where one is expected"))
 			    (schemify node)))
 	    (else
-	     (error "unknown compiler continuation for VALUES" cont)))))
+	     (assertion-violation 'values
+				  "unknown compiler continuation for VALUES" cont)))))
   (lambda (frame)
     (sequentially (nary-primitive-protocol 0)
 		  (instruction (enum op closed-values)))))
@@ -597,6 +598,13 @@
                   (instruction (enum op call-external-value))
                   (instruction (enum op return)))))
 
+(define-n-ary-compiler-primitive 'call-external-value-2 value-type 1
+  #f                                         ;Could be done
+  (lambda (frame)
+    (sequentially (nary-primitive-protocol 1)
+                  (instruction (enum op call-external-value-2))
+                  (instruction (enum op return)))))
+
 (let ((n-ary-constructor
         (lambda (name type type-byte)
 	  (define-n-ary-compiler-primitive name type 0
@@ -754,9 +762,9 @@
 ; = and < and so forth take two or more arguments.
 
 (let ((define=<
-	(lambda (id opcode)
+	(lambda (id opcode type)
 	  (define-compiler-primitive id
-	    (proc (real-type real-type &rest real-type) boolean-type)
+	    (proc (type type &rest type) boolean-type)
 	    (lambda (node depth frame cont)
 	      (if (node-ref node 'type-error)
 		  (compile-unknown-call node depth frame cont)
@@ -778,11 +786,14 @@
 			      (instruction opcode)
 			      (instruction (enum op binary-comparison-reduce2))
 			      (instruction (enum op return)))))))))
-  (define=< '= (enum op =))
-  (define=< '< (enum op <))
-  (define=< '> (enum op >))
-  (define=< '<= (enum op <=))
-  (define=< '>= (enum op >=)))
+  (define=< '= (enum op =) real-type)
+  (define=< '< (enum op <) real-type)
+  (define=< '> (enum op >) real-type)
+  (define=< '<= (enum op <=) real-type)
+  (define=< '>= (enum op >=) real-type)
+  (define=< 'char<? (enum op char<?) char-type)
+  (define=< 'char=? (enum op char=?) char-type)
+  (define=< 'string=? (enum op string=?) string-type))
 
 ; Returns code to apply OPCODE to IDENTITY and ARGUMENT.
 
@@ -952,19 +963,20 @@
 						  " arguments where one is expected")
 				   (schemify node)))
 		   (else
-		    (error "unknown compiler continuation" (enumerand->name regular op) cont)))))
+		    (assertion-violation 'define-encode/decode
+					 "unknown compiler continuation" (enumerand->name regular op) cont)))))
 	      (direct-closed-compilator regular))))))
 
-  (define-encode/decode 'encode-char 
+  (define-encode/decode 'char->utf
     (proc (exact-integer-type char-type value-type exact-integer-type exact-integer-type)
 	  (make-some-values-type (list boolean-type value-type)))
     5 2
-    (enum op encode-char) (enum op encode-char!))
+    (enum op char->utf) (enum op char->utf!))
 
-  (define-encode/decode 'decode-char 
+  (define-encode/decode 'utf->char
     (proc (exact-integer-type value-type exact-integer-type exact-integer-type)
 	  (make-some-values-type (list value-type value-type)))
     4 2
-    (enum op decode-char) (enum op decode-char!)))
+    (enum op utf->char) (enum op utf->char!)))
 
   
