@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; Interfaces
 ;
@@ -40,8 +42,8 @@
   ((ref-method int) name))
 
 (define (interface-member? int name)
-  (mvlet (((base-name type)
-	     (interface-ref int name)))
+  (receive (base-name type)
+      (interface-ref int name)
     base-name))
 
 ; The generic walk function.
@@ -111,11 +113,11 @@
 			       (let loop ((ints ints))
 				 (if (null? ints)
 				     (values #f #f)
-				     (mvlet (((new-name type)
-					      (interface-ref (car ints) name)))
-					    (if new-name
-						(values new-name type)
-						(loop (cdr ints)))))))
+				     (receive (new-name type)
+					 (interface-ref (car ints) name)
+				       (if new-name
+					   (values new-name type)
+					   (loop (cdr ints)))))))
 			     (lambda (proc)
 			       (for-each (lambda (int)
 					   (for-each-declaration proc int))
@@ -153,17 +155,18 @@
 ; does not allow any names to be seen.
 
 (define (make-modified-interface-maker commands)
-  (if (and (proper-list? commands)
+  (if (and (list? commands)
 	   (every okay-command? commands))
-      (mvlet (((alist hidden default)
-	         (process-commands commands)))
+      (receive (alist hidden default)
+	  (process-commands commands)
 	(lambda (interface)
 	  (let ((lookup (make-lookup alist hidden default interface))
 		(walker (make-interface-walker alist hidden default interface)))
 	    (let ((int (make-interface lookup walker #f)))
 	      (note-reference-to-interface! interface int)
 	      int))))
-      (error "badly-formed structure modifiers" commands)))
+      (assertion-violation 'make-modified-interface-maker
+			   "badly-formed structure modifiers" commands)))
 
 ; We process COMMANDS and compute three values:
 ;   - an alist mapping visible names to their real names in the package
@@ -187,20 +190,20 @@
 			alist)
 		hidden
 		default)
-	(mvlet (((alist hidden default)
-		   (let ((proc (case (caar commands)
-				 ((prefix) process-prefix)
-				 ((expose) process-expose)
-				 ((hide)   process-hide)
-				 ((alias)  process-alias)
-				 ((rename) process-rename))))
-		     (proc (cdar commands) alist hidden default))))
+	(receive (alist hidden default)
+	    (let ((proc (case (caar commands)
+			  ((prefix) process-prefix)
+			  ((expose) process-expose)
+			  ((hide)   process-hide)
+			  ((alias)  process-alias)
+			  ((rename) process-rename))))
+	      (proc (cdar commands) alist hidden default))
 	  (loop alist hidden default (cdr commands))))))
 
 ; Checks that COMMAND is properly formed.
 
 (define (okay-command? command)
-  (and (proper-list? command)
+  (and (list? command)
        (pair? command)
        (symbol? (car command))
        (pair? (cdr command))
@@ -213,7 +216,7 @@
 	    (every symbol? args))
 	   ((alias rename)
 	    (every (lambda (spec)
-		     (and (proper-list? spec)
+		     (and (list? spec)
 			  (= 2 (length spec))
 			  (symbol? (car spec))
 			  (symbol? (cadr spec))))
@@ -221,16 +224,6 @@
 	   (else
 	    #f)))))
 
-; Checks that L is a proper list.
-
-(define (proper-list? l)
-  (cond ((null? l)
-	 #t)
-	((pair? l)
-	 (proper-list? (cdr l)))
-	(else
-	 #f)))
-
 ; We add the prefix to the names in ALIST and HIDDEN.  If DEFAULT is already
 ; a prefix we add this one to it, otherwise the prefix is the new default.
 
@@ -384,8 +377,8 @@
 
 (define (walk-alist proc alist hidden interface)
   (for-each (lambda (pair)
-	      (mvlet (((base-name type)
-		       (interface-ref interface (cdr pair))))
+	      (receive (base-name type)
+		  (interface-ref interface (cdr pair))
 		(let ((new-name (car pair)))
 		  (if (and base-name (not (memq new-name hidden)))
 		      (proc new-name
