@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; Names (symbols) and generated names.
 
@@ -57,37 +59,37 @@
 	((generated? name)
 	 (name-hash (generated-name name)))
 	(else
-	 (error "invalid name" name))))
+	 (assertion-violation 'name-hash "invalid name" name))))
 
 (define make-name-table
   (make-table-maker eq? name-hash))
 
 ; Used by QUOTE to turn generated names back into symbols
 
-(define (desyntaxify thing)
-  (cond ((or (boolean? thing) (null? thing) (number? thing)
-	     (symbol? thing) (char? thing))
-	 thing)
-	((string? thing)
-	 (make-immutable! thing))
-	((generated? thing)
-	 (desyntaxify (generated-name thing)))
-	((pair? thing)
-	 (make-immutable!
-	  (cons (desyntaxify (car thing))
-		(desyntaxify (cdr thing)))))
-	((vector? thing)
-	 (make-immutable!
-	  (let ((new (make-vector (vector-length thing) #f)))
-	    (let loop ((i 0))
-	      (if (>= i (vector-length thing))
-		  new
-		  (begin
-		    (vector-set! new i (desyntaxify (vector-ref thing i)))
-		    (loop (+ i 1))))))))
-	(else
-	 (warn "invalid datum in quotation" thing)
-	 thing)))
+(define (desyntaxify thing0)
+  (let desyntaxify ((thing thing0))
+    (cond ((or (boolean? thing) (null? thing) (number? thing)
+	       (symbol? thing) (char? thing))
+	   thing)
+	  ((string? thing)
+	   (make-immutable! thing))
+	  ((generated? thing)
+	   (desyntaxify (generated-name thing)))
+	  ((pair? thing)
+	   (make-immutable!
+	    (cons (desyntaxify (car thing))
+		  (desyntaxify (cdr thing)))))
+	  ((vector? thing)
+	   (make-immutable!
+	    (let ((new (make-vector (vector-length thing) #f)))
+	      (let loop ((i 0))
+		(if (>= i (vector-length thing))
+		    new
+		    (begin
+		      (vector-set! new i (desyntaxify (vector-ref thing i)))
+		      (loop (+ i 1))))))))
+	  (else
+	   (syntax-violation 'quote "invalid datum in quotation" thing)))))
 
 ;----------------
 ; Qualified names
