@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; --------------------
 ; Operators (= special operators and primitives)
@@ -32,14 +34,16 @@
 		 (set-operator-type! probe type))
 		((symbol? type)		; 'leaf or 'internal
 		 (if (not (eq? type previous-type))
-		     (warn "operator type inconsistency" name type previous-type)))
+		     (warning 'get-operator
+			      "operator type inconsistency" name type previous-type)))
 		((subtype? type previous-type)  ;Improvement
 		 (set-operator-type! probe type))
 		((not (subtype? previous-type type))
-		 (warn "operator type inconsistency"
-		       name
-		       (type->sexp previous-type 'foo)
-		       (type->sexp type 'foo))))
+		 (warning 'get-operator
+			  "operator type inconsistency"
+			  name
+			  (type->sexp previous-type 'foo)
+			  (type->sexp type 'foo))))
 	  probe)
 	(let* ((uid *operator-uid*)
 	       (op (make-operator type
@@ -51,7 +55,8 @@
 				  uid
 				  name)))
 	  (if (>= uid number-of-operators)
-	      (warn "too many operators" (operator-name op) (operator-type op)))
+	      (warning 'get-operator
+		       "too many operators" (operator-name op) (operator-type op)))
 	  (set! *operator-uid* (+ *operator-uid* 1))
 	  (table-set! operators-table (operator-name op) op)
 	  (vector-set! the-operators uid op)
@@ -88,7 +93,7 @@
 ; the S-expression representation of the expression.  E.g. for
 ; literals, the form is the literal value; for variables the form is
 ; the variable name; for IF expressions the form is a 4-element list
-; (ignored test con alt).  Nodes also have a tag identifying what kind
+; (<if> test con alt).  Nodes also have a tag identifying what kind
 ; of node it is (literal, variable, if, etc.) and a property list.
 
 (define-record-type node :node
@@ -108,6 +113,7 @@
   (let ((probe (assq key (node-plist node))))
     (if probe (cdr probe) #f)))
 
+; removes property if value is #f
 (define (node-set! node key value) ;gross
   (if value
       (let ((probe (assq key (node-plist node))))
@@ -160,6 +166,7 @@
 (define operator/begin       (get-operator 'begin syntax-type))
 (define operator/name        (get-operator 'name 'leaf))
 (define operator/letrec      (get-operator 'letrec))
+(define operator/letrec*     (get-operator 'letrec*))
 (define operator/pure-letrec (get-operator 'pure-letrec))
 (define operator/literal     (get-operator 'literal))
 (define operator/quote       (get-operator 'quote syntax-type))
