@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; Optimizers
 
@@ -12,9 +14,9 @@
     (apply-optimizers (map (lambda (name)
 			     (or (table-ref optimizers-table name)
 				 (begin
-				   (signal 'note
-					   "optional optimization pass not invoked"
-					   name)
+				   (note 'get-optimizer
+					 "optional optimization pass not invoked"
+					 name)
 				   (lambda (forms package) forms))))
 			   names)
 		      forms
