@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2005 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; Primops.
 
@@ -30,4 +32,4 @@
 
 (define (get-primop name)
   (or (table-ref primop-table name)
-      (error "unknown compiler primitive" name)))
+      (assertion-violation 'get-primop "unknown compiler primitive" name)))
