@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; The value of $NOTE-FILE-PACKAGE is called whenever a file is loaded into
 ; a package.  env/debug.scm uses this to associate packages with files so
@@ -13,26 +15,27 @@
 (define (read-forms pathname package script?)
   (let* ((filename (namestring pathname #f *scheme-file-type*))
          (truename (translate filename))
-   	 (port (open-input-file truename)))
+   	 (port (open-input-file truename))
+	 (reader (package-reader package)))
     (dynamic-wind
      (lambda ()
        (if (not port)
-	   (error "attempt to throw back into READ-FORMS")))
+	   (assertion-violation 'read-forms "attempt to throw back into READ-FORMS")))
      (lambda ()
        ((fluid-cell-ref $note-file-package) filename package)
        (let ((o-port (current-noise-port)))
 	 (display truename o-port)
 	 (force-output o-port)
-	 (really-read-forms port script?)))
+	 (really-read-forms port reader script?)))
      (lambda ()
        (close-input-port port)
        (set! port #f)))))
 
-(define (really-read-forms port script?)
+(define (really-read-forms port reader script?)
   (if script?
       (skip-line port))
   (let loop ((forms '()))
-    (let ((form (read port)))
+    (let ((form (reader port)))
       (if (eof-object? form)
 	  (reverse forms)
 	  (loop (cons form forms))))))
