@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; Scanning structures and processing package clauses.
 
@@ -13,7 +15,10 @@
 	(structure-seen '())
 	(packages '()))
     (letrec ((recur
-	      (lambda (structure)
+	      (lambda (structure visited)
+		(if (memq (structure-package structure) visited)
+		    (warning 'collect-packages "cycle in structures dependencies"
+			     structure visited))
 		(if (not (memq structure structure-seen))
 		    (begin
 		      (set! structure-seen (cons structure structure-seen))
@@ -22,21 +27,25 @@
 			    (begin
 			      (set! package-seen (cons package package-seen))
 			      (if (include-this-package? package)
-				  (begin
-				    (for-each recur (package-opens package))
+				  (let ((visited (cons package visited)))
+				    (for-each (lambda (struct)
+						(recur struct visited))
+					      (package-opens package))
 				    (for-each (lambda (name+struct)
-						(recur (cdr name+struct)))
+						(recur (cdr name+struct) visited))
 					      (package-accesses package))
 				    (set! packages (cons package packages))))))))))))
-      (for-each recur structs)
+      (for-each (lambda (struct)
+		  (recur struct '()))
+		structs)
       (reverse packages))))
 
-; Walk through PACKAGE's clauses to find the source code.  The relevent
+; Walk through PACKAGE's clauses to find the source code.  The relevant
 ; clauses are:
-;   (file name ...)
+;   (files name ...)
 ;   (begin form ...)
 ;   (define-all-operators)
-;   (usual-transforms)
+;   (usual-transforms name ...)
 ;
 ; Returns a list of pairs (file . (node1 node2 ...)), a list of names
 ; of standard transforms, and a boolean value which is true if the package
@@ -47,35 +56,46 @@
 	 (dir (if config-file
 		  (file-name-directory config-file)
 		  #f)))
-    (fold->3 (lambda (clause stuff transforms primitives?)
-	       (case (car clause)
-		 ((files)
-		  (values (read-files (cdr clause) stuff dir package)
-			  transforms
-			  primitives?))
-		 ((begin)
-		  (values (cons (cons config-file (cdr clause))
-				stuff)
-			  transforms
-			  primitives?))
-		 ((integrate)
-		  (set-package-integrate?! package
-					   (or (null? (cdr clause))
-					       (cadr clause)))
-		  (values stuff transforms primitives?))
-		 ((optimize)
-		  (values stuff transforms primitives?))
-		 ((define-all-operators)
-		  (values stuff transforms #t))
-		 ((usual-transforms)
-		  (values stuff
-			  (append (cdr clause) transforms)
-			  primitives?))
-		 (else
-		  (error "unrecognized define-structure keyword"
-			 clause))))
-	     (reverse (package-clauses package))
-	     '() '() #f)))
+    (call-with-values
+	(lambda ()
+	  (fold->3 (lambda (clause stuff transforms primitives?)
+		     (case (car clause)
+		       ((files)
+			(values (read-files (cdr clause) stuff dir package)
+				transforms
+				primitives?))
+		       ((begin)
+			(values (cons (cons config-file (cdr clause))
+				      stuff)
+				transforms
+				primitives?))
+		       ((integrate)
+			(set-package-integrate?! package
+						 (or (null? (cdr clause))
+						     (cadr clause)))
+			(values stuff transforms primitives?))
+		       ((optimize)
+			(values stuff transforms primitives?))
+		       ((define-all-operators)
+			(values stuff transforms #t))
+		       ((usual-transforms)
+			(values stuff
+				(append (reverse (cdr clause)) transforms)
+				primitives?))
+		       ((reader)
+			(let ((r (force (comp-env-macro-eval (package->environment package)))))
+			  (set-package-reader! package ((car r) (cadr clause) (cdr r))))
+			(values stuff transforms primitives?))
+		       (else
+			(assertion-violation 'package-source
+					     "unrecognized define-structure keyword"
+					     clause))))
+		   (package-clauses package)
+		   '() '() #f))
+      (lambda (stuff transforms primitives?)
+	(values (reverse stuff)
+		(reverse transforms)
+		primitives?)))))
 
 ; Also prints out the filenames (courtesy of READ-FORMS).
 
@@ -88,7 +108,7 @@
 	    (display #\space (current-noise-port))
 	    (cons (cons file (read-forms file package #f))
 		  stuff)))
-	(reverse all-files)
+	all-files
 	stuff))
 
 (define (package-optimizer-names package)
@@ -112,15 +132,17 @@
 	   (if (binding? binding)
 	       (let ((have-type (binding-type binding)))
 		 (if (not (compatible-types? have-type want-type))
-		     (warn "Type in interface doesn't match binding"
-			   name
-			   `(binding: ,(type->sexp have-type #t))
-			   `(interface: ,(type->sexp want-type #t))
-			   structure)))
+		     (warning 'check-structure
+			      "Type in interface doesn't match binding"
+			      name
+			      `(binding: ,(type->sexp have-type #t))
+			      `(interface: ,(type->sexp want-type #t))
+			      structure)))
 	       (set! undefined (cons name undefined))))
 	 structure)
     (if (not (null? undefined))
-	(warn "Structure has undefined exports"
-	      structure
-	      undefined))))
+	(warning 'check-structure
+		 "Structure has undefined exports"
+		 structure
+		 undefined))))
 
