@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Martin Gasbichler, Mike Sperber
 
 ; schemify
 
@@ -145,15 +147,20 @@
 (define-schemifier 'letrec syntax-type
   (lambda (node env)
     (let ((form (node-form node)))
-      (schemify-letrec (cadr form) (caddr form) env))))
+      (schemify-letrec 'letrec (cadr form) (caddr form) env))))
+
+(define-schemifier 'letrec* syntax-type
+  (lambda (node env)
+    (let ((form (node-form node)))
+      (schemify-letrec 'letrec* (cadr form) (caddr form) env))))
 
 (define-schemifier 'pure-letrec syntax-type
   (lambda (node env)
     (let ((form (node-form node)))
-      (schemify-letrec (cadr form) (cadddr form) env))))
+      (schemify-letrec 'letrec (cadr form) (cadddr form) env))))
 
-(define (schemify-letrec specs body env)
-  `(letrec ,(map (lambda (spec)
+(define (schemify-letrec op specs body env)
+  `(,op ,(map (lambda (spec)
 		   (schemify-nodes spec env))
 		 specs)
      ,(schemify-node body env)))
