@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber, Robert Ransom
 
 ; Macro expansion.
 
@@ -37,9 +39,9 @@
   (let ((new-form (destructure-define form)))
     (if new-form
 	 (begin
-	   (environment-define! env (cadr new-form) usual-variable-type)
+	   (comp-env-define! env (cadr new-form) usual-variable-type)
 	   new-form)
-	 (syntax-error "ill-formed definition" form))))
+	 (syntax-violation 'syntax-rules "ill-formed definition" form))))
 
 (define (expand-define form env)
   (make-node operator/define
@@ -53,18 +55,18 @@
 	   (name? (cadr form)))
       (let ((name (cadr form))
 	    (source (caddr form))
-	    (package (extract-package-from-environment env)))
-	(environment-define! env
-			     name
-			     syntax-type
-			     (process-syntax (if (null? (cdddr form))
-						 source
-						 `(cons ,source ',(cadddr form)))
-					     env
-					     name
-					     package))
+	    (package (extract-package-from-comp-env env)))
+	(comp-env-define! env
+			  name
+			  syntax-type
+			  (process-syntax (if (null? (cdddr form))
+					      source
+					      `(cons ,source ',(cadddr form)))
+					  env
+					  name
+					  package))
 	'())
-      `(,(syntax-error "ill-formed syntax definition" form))))
+      (syntax-violation 'define-syntax "ill-formed syntax definition" form)))
 
 ; This is used by the ,expand command.
 
@@ -80,8 +82,8 @@
 		 (let* ((new-form (destructure-define form))
 			(temp (if new-form
 				  (expand-define new-form env)
-				  (syntax-error "ill-formed definition"
-						form))))
+				  (syntax-violation 'expand "ill-formed definition"
+						    form))))
 		   (loop more-forms (cons temp expanded))))
 		((define-syntax? form)
 		 (loop more-forms
@@ -144,7 +146,8 @@
       (let ((pat (cadr form))
 	    (operator (car form)))
 	(cond ((pair? pat)
-	       (if (and (names? (cdr pat))
+	       (if (and (name? (car pat))
+			(names? (cdr pat))
 			(not (null? (cddr form))))
 		   `(,operator ,(car pat)
 			       (,operator/lambda ,(cdr pat)
@@ -203,7 +206,8 @@
 		    (values (reverse defs)
 			    exps)))
 	      (lambda (defs exps)
-		(expand-letrec (map car defs)
+		(expand-letrec operator/letrec
+			       (map car defs)
 			       (map cdr defs)
 			       exps
 			       env))))))))
@@ -229,10 +233,8 @@
 					(cons (cons node
 						    (caddr new-form))
 					      defs)))
-		     (values defs
-			     (cons (syntax-error "ill-formed definition" form)
-				   more-forms)
-			     env))))
+		     (syntax-violation 'scan-body-forms
+				       "ill-formed definition" form))))
 	      ((begin? form)
 	       (call-with-values
 		(lambda ()
@@ -250,8 +252,9 @@
 	       (values defs (cons form more-forms) env))))))
 
 (define (body-lossage node env)
-  (syntax-error "definitions and expressions intermixed"
-		(schemify node env)))
+  (syntax-violation 'body
+		    "definitions and expressions intermixed"
+		    (schemify node env)))
 
 ;--------------------
 ; Expands all macros in FORM and returns a node.
@@ -287,7 +290,7 @@
 	 (expand-literal form))
 	;; ((qualified? form) ...)
 	(else
-	 (expand (syntax-error "invalid expression" form) env))))
+	 (syntax-violation 'expand "invalid expression" form))))
 
 (define (expand-list exps env)
   (map (lambda (exp)
@@ -301,7 +304,7 @@
   (if (list? exp)
       (make-node operator/call
 		 (cons proc-node (expand-list (cdr exp) env)))
-      (expand (syntax-error "invalid expression" exp) env)))
+      (syntax-violation 'expand-call "invalid expression" exp)))
 
 ; An environment is a procedure that takes a name and returns one of
 ; the following:
@@ -334,10 +337,10 @@
 				  env-of-use))
    (lambda (new-form new-env)
      (if (eq? new-form form)
-	 (expand (syntax-error "use of macro doesn't match definition"
-			       (cons (schemify (car form) env-of-use)
-				     (desyntaxify (cdr form))))
-		 env-of-use)
+	 (syntax-violation (schemify (car form) env-of-use)
+			   "use of macro doesn't match definition"
+			   (cons (schemify (car form) env-of-use)
+				 (desyntaxify (cdr form))))
 	 (expand new-form new-env)))))
 
 ;--------------------
@@ -365,11 +368,11 @@
 
 (define-expander 'define
   (lambda (op op-node exp env)
-    (expand (syntax-error (if (define? exp)
-			      "definition in expression context"
-			      "ill-formed definition")
-			  exp)
-	    env)))
+    (syntax-violation 'define
+		      (if (destructure-define exp)
+			  "definition in expression context"
+			  "ill-formed definition")
+		      exp)))
 
 ; Remove generated names from quotations.
 
@@ -377,7 +380,7 @@
   (lambda (op op-node exp env)
     (if (this-long? exp 2)
 	(make-node op (list op (desyntaxify (cadr exp))))
-	(expand (syntax-error "invalid expression" exp) env))))
+	(syntax-violation 'quote "invalid expression" exp))))
 
 ; Don't evaluate, but don't remove generated names either.  This is
 ; used when writing macro-defining macros.  Once we have avoided the
@@ -387,7 +390,7 @@
   (lambda (op op-node exp env)
     (if (this-long? exp 2)
 	(make-node operator/quote (list op (cadr exp)))
-	(expand (syntax-error "invalid expression" exp) env))))
+	(syntax-violation 'code-quote "invalid expression" exp))))
 
 ; Convert one-armed IF to two-armed IF.
 
@@ -403,7 +406,7 @@
 	   (make-node op
 		      (cons op (expand-list (cdr exp) env))))
 	  (else
-	   (expand (syntax-error "invalid expression" exp) env)))))
+	   (syntax-violation 'if "invalid expression" exp)))))
 
 (define (unspecific-node)
   (make-node operator/unspecific '(unspecific)))
@@ -419,18 +422,17 @@
 (define (expand-structure-ref form env expander)
   (let ((struct-node (expand (cadr form) env))
 	(lose (lambda ()
-		(expand (syntax-error "invalid structure reference" form)
-			env))))
+		(syntax-violation 'structure-ref "invalid structure reference" form))))
     (if (and (this-long? form 3)
 	     (name? (caddr form))
 	     (name-node? struct-node))
 	(let ((b (node-ref struct-node 'binding)))
 	  (if (and (binding? b)
 		   (binding-static b)) ; (structure? ...)
-	      (expand (generate-name (desyntaxify (caddr form))
-				     (binding-static b)
-				     (node-form struct-node))
-		      env)
+	      (expander (generate-name (desyntaxify (caddr form))
+				       (binding-static b)
+				       (node-form struct-node))
+			env)
 	      (lose)))
 	(lose))))
 
@@ -448,7 +450,7 @@
     (if (and (at-least-this-long? exp 3)
 	     (names? (cadr exp)))
 	(expand-lambda (cadr exp) (cddr exp) env)
-	(expand (syntax-error "invalid expression" exp) env))))
+	(syntax-violation 'lambda "invalid expression" exp))))
 
 (define (expand-lambda names body env)
   (call-with-values
@@ -483,9 +485,9 @@
     (if (and (this-long? exp 3)
 	     (name? (cadr exp)))
 	(make-node op (cons op (expand-list (cdr exp) env)))
-	(expand (syntax-error "invalid expression" exp) env))))
+	(syntax-violation 'set! "invalid expression" exp))))
 
-(define-expander 'letrec
+(define (letrec-expander op/letrec)
   (lambda (op op-node exp env)
     (if (and (at-least-this-long? exp 3)
 	     (let-specs? (cadr exp)))
@@ -495,16 +497,22 @@
 			       (make-node operator/name (car spec)))
 			     specs))
 		 (env (bind (map car specs) names env)))
-	    (expand-letrec names (map cadr specs) body env)))
-	(expand (syntax-error "invalid expression" exp) env))))
+	    (expand-letrec op/letrec names (map cadr specs) body env)))
+	(syntax-violation 'letrec "invalid expression" exp))))
 
-(define (expand-letrec names values body env)
+(define-expander 'letrec
+  (letrec-expander operator/letrec))
+
+(define-expander 'letrec*
+  (letrec-expander operator/letrec*))
+
+(define (expand-letrec op/letrec names values body env)
   (let* ((new-specs (map (lambda (name value)
 			   (list name
 				 (expand value env)))
 			 names
 			 values)))
-    (make-node operator/letrec
+    (make-node op/letrec
 	       (list 'letrec new-specs (expand-body body env)))))
 
 (define-expander 'loophole
@@ -513,7 +521,7 @@
 	(make-node op (list op
 			    (sexp->type (desyntaxify (cadr exp)) #t)
 			    (expand (caddr exp) env)))
-	(expand (syntax-error "invalid expression" exp) env))))
+	(syntax-violation 'loophole "invalid expression" exp))))
 
 (define-expander 'let-syntax
   (lambda (op op-node exp env)
@@ -531,35 +539,36 @@
 								  env)))
 				  specs)
 			     env)))
-	(expand (syntax-error "invalid expression" exp) env))))
+	(syntax-violation 'let-syntax "invalid expression" exp))))
 
 (define-expander 'letrec-syntax
   (lambda (op op-node exp env)
     (if (and (at-least-this-long? exp 3)
 	     (let-specs? (cadr exp)))
-	(let ((specs (cadr exp)))
-	  (expand-body
-	    (cddr exp)
-	    (bindrec (map car specs)
-		     (lambda (new-env)
-		       (map (lambda (spec)
-			      (make-binding syntax-type
-					    (list 'letrec-syntax)
-					    (process-syntax (cadr spec)
-							    new-env
-							    (car spec)
-							    new-env)))
-			    specs))
-		     env)))
-	(expand (syntax-error "invalid expression" exp) env))))
+	(let* ((specs (cadr exp))
+	       (bindings (map (lambda (spec)
+				(make-binding syntax-type
+					      (list 'letrec-syntax)
+					      'unassigned))
+			      specs))
+	       (new-env (bind (map car specs) bindings env)))
+	  (for-each (lambda (spec binding)
+		      (set-binding-static! binding
+					   (process-syntax (cadr spec)
+							   new-env
+							   (car spec)
+							   new-env)))
+		    specs bindings)
+	  (expand-body (cddr exp) new-env))
+	(syntax-violation 'letrec-syntax "invalid expression" exp))))
     
 (define (process-syntax form env name env-or-package)
-  (let ((eval+env (force (environment-macro-eval env))))
-    (make-transform ((car eval+env) form (cdr eval+env))
-		    env-or-package
-		    syntax-type
-		    form
-		    name)))
+  (let ((eval+env (force (comp-env-macro-eval env))))
+    (make-transform/macro ((car eval+env) form (cdr eval+env))
+			  env-or-package
+			  syntax-type
+			  form
+			  name)))
 
 ; This just looks up the names that the LAP code will want and replaces them
 ; with the appropriate node.
@@ -577,7 +586,7 @@
 				(expand-name (cadr exp) env))
 			      (caddr exp))
 			. ,(cdddr exp)))
-	(expand (syntax-error "invalid expression" exp) env))))
+	(syntax-violation 'lap "invalid expression" exp))))
 
 ; --------------------
 ; Syntax checking utilities
@@ -612,7 +621,8 @@
 ; Utilities
 
 (define (literal? exp)
-  (or (number? exp) (char? exp) (string? exp) (boolean? exp)))
+  (or (number? exp) (char? exp) (string? exp) (boolean? exp)
+      (code-vector? exp)))
 
 (define (syntax? d)
   (cond ((operator? d)
