@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; A thingie (placecard?) is used to hold a spot for a location that is to be
 ; found later.  The compiler sticks them in templates and the module system
@@ -8,9 +10,9 @@
 ; by flatload, which can't handle them.
 
 (define-record-type thingie :thingie
-  (make-thingie binding name want-type)
+  (make-thingie binding name assigned?)
   thingie?
   (binding thingie-binding)
   (name thingie-name)
-  (want-type thingie-want-type))
+  (assigned? thingie-assigned? set-thingie-assigned?!))
 
