@@ -1,3 +1,7 @@
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Mike Sperber
+
 ;; This replaces trans-id REF in Reppy's code
 
 (define-synchronized-record-type trans-id :trans-id
@@ -23,11 +27,14 @@
 
 (define (trans-id-set-value! trans-id value)
   (cond
-   ((not value) (error "trans-id value can't be #f" trans-id value))
+   ((not value)
+    (assertion-violation 'trans-id-set-value! "trans-id value can't be #f"
+			 trans-id value))
    ((trans-id-value trans-id)
-    (error "trans-id is already assigned"))
+    (assertion-violation 'trans-id-set-value! "trans-id is already assigned"
+			 trans-id value))
    (else
-    (set-trans-id-value! trans-id value))))
+    (set-trans-id-value! trans-id value)) ))
 
 (define (trans-id-cancelled? trans-id)
   (and (trans-id-value trans-id) #t))
