@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber, Robert Ransom, Marcel Turino
 
 ; Various data structures used by the compiler, module system, etc.
 
@@ -8,7 +10,7 @@
   (open scheme-level-2
 	define-record-types tables bitwise
 	features ;make-immutable!
-	util simple-signals)
+	util low-exceptions)
   (files (bcomp mtype))
   (optimize auto-integrate))
 
@@ -28,10 +30,12 @@
 		    (transforms transforms-interface))
   (open scheme-level-2
 	define-record-types tables
-	simple-signals
+	low-exceptions
 	meta-types	;sexp->type
 	bindings	;same-denotation?
-	features)	;make-immutable! string-hash
+	features	;make-immutable! string-hash
+	syntax-transformers
+	compiler-envs)
   (files (bcomp name)
 	 (bcomp transform))
   (optimize auto-integrate))
@@ -47,7 +51,8 @@
 				   thingie?
 				   thingie-binding
 				   thingie-name
-				   thingie-want-type)
+				   thingie-assigned?
+				   set-thingie-assigned?!)
   (open scheme-level-2 define-record-types)
   (optimize auto-integrate)
   (files (bcomp thingie)))
@@ -55,8 +60,8 @@
 ; Nodes
 
 (define-structure compiler-envs compiler-envs-interface
-  (open scheme-level-2
-	meta-types names bindings)
+  (open scheme-level-2 define-record-types
+	meta-types bindings)
   (files (bcomp cenv))
   (optimize auto-integrate))
 
@@ -64,7 +69,7 @@
   (open scheme-level-2
 	meta-types names packages packages-internal
 	compiler-envs bindings transforms
-	simple-signals define-record-types tables
+	low-exceptions define-record-types tables
 	util)
   (files (bcomp node)
 	 (bcomp schemify))
@@ -77,22 +82,30 @@
   (open scheme-level-2 util
 	meta-types names bindings
 	nodes compiler-envs
-	simple-signals tables fluids
+	low-exceptions tables fluids
 	var-utilities
 	transforms
+        code-vectors
 	features)		;make-immutable!
   (files (bcomp syntax))
   (optimize auto-integrate))
 
+(define-structure syntax-rules-compiler (export compile-rules)
+  (open scheme-level-2 (subset util (receive)) names syntax-rules-data)
+  (files (bcomp syntax-rules-compiler)))
+
 (define-structure usual-macros usual-macros-interface
   (open scheme-level-2
 	names		;name?
 	fluids		;used in definition of %file-name%
-	code-quote
+	code-quotation
+	syntax-rules-compiler
 	util
-	tables simple-signals)
+	tables 
+	low-exceptions
+	syntax-transformers)
   (files (bcomp usual)
-	 (bcomp rules)))
+	 (bcomp syntax-rules)))
 
 ; Little utilities to be phased out by changing the format of lambda var lists
 ; in nodes.
@@ -123,14 +136,14 @@
 ; Determining stack usage.  No longer used.
 ;
 ;(define-structure stack-check (export maximum-stack-use)
-;  (open scheme-level-2 architecture code-vectors simple-signals)
+;  (open scheme-level-2 architecture code-vectors low-exceptions)
 ;  (files (bcomp stack-check))
 ;  (optimize auto-integrate))
 
 ; Compiler back end
 
 (define-structure segments segments-interface
-  (open scheme-level-2 util tables simple-signals fluids
+  (open scheme-level-2 util tables low-exceptions fluids
 	define-record-types
 	bitwise vm-data
 	code-vectors
@@ -147,7 +160,7 @@
 (define-structure primops primops-interface
   (open scheme-level-2 tables define-record-types
 	meta-types
-	simple-signals)
+	low-exceptions)
   (files (bcomp primop))
   (optimize auto-integrate))
 
@@ -159,14 +172,14 @@
 	primops
 	var-utilities		;n-ary?
 	util			;last
-	simple-signals)
+	low-exceptions)
   (files (bcomp recon)))
 
 ; The compiler itself.
 
 (define-structures ((compiler compiler-interface)
 		    (bc-generation bc-generation-interface))
-  (open scheme-level-2 util simple-signals
+  (open scheme-level-2 util low-exceptions
 	features		;force-output
 	enumerated		;enumerand->name
 	ascii
@@ -193,7 +206,7 @@
 	architecture			; two-byte-limit
 	templates			; template-overhead
 	debug-data-internal		; new-debug-data
-	simple-signals			; error
+	low-exceptions			; error
 	thingies)
   (files (bcomp frame))
   (optimize auto-integrate))
@@ -206,7 +219,8 @@
   (open scheme-level-2
 	fluids filenames cells
 	features		;current-noise-port force-output
-	simple-signals          ;error
+	low-exceptions          ;error
+	(subset packages-internal (package-reader))
 	)
   (files (bcomp read-form)))
 
@@ -214,7 +228,7 @@
 ; Live-variable analysis for closures.
 
 (define-structure flat-environments (export flatten-form)
-  (open scheme-level-2 nodes simple-signals
+  (open scheme-level-2 nodes low-exceptions
 	optimizer primops
 	util			;every
 	var-utilities)
@@ -226,8 +240,8 @@
 (define-structure interfaces interfaces-interface
   (open scheme-level-2
 	define-record-types tables
-	util			;filter every mvlet symbol-append
-	simple-signals		;error
+	util			;filter every receive symbol-append
+	low-exceptions		;error
 	weak			;populations
 	meta-types)
   (files (bcomp interface))
@@ -237,7 +251,7 @@
 		    (packages-internal packages-internal-interface)
 		    (undefined undefined-interface))
   (open scheme-level-2
-	define-record-types tables fluids simple-signals cells
+	define-record-types tables fluids low-exceptions cells
 	util features locations weak
         meta-types interfaces
 	names bindings
@@ -252,16 +266,17 @@
   (open scheme-level-2 util
 	packages packages-internal
 	meta-types bindings
+	compiler-envs
 	reading-forms
 	filenames
-	simple-signals
+	low-exceptions
 	features		;current-noise-port force-output
 	)
   (files (bcomp scan-package)))
 
 (define-structure optimizer optimizer-interface
   (open scheme-level-2
-	simple-signals tables
+	low-exceptions tables
 	util)
   (files (bcomp optimize)))
 
@@ -286,10 +301,12 @@
 
 (define-structure defpackage defpackage-interface
   (open scheme-level-2
-	packages syntactic usual-macros types
+	packages 
+	(subset packages-internal (set-package-reader!))
+	syntactic usual-macros types
 	interfaces
 	source-file-names	;%file-name%
-	simple-signals		;error
+	low-exceptions		;error
 	tables)
   (files (bcomp module-language)
 	 (bcomp config)))
@@ -315,7 +332,7 @@
 	reconstruction
 	var-utilities
 	define-record-types
-	util simple-signals tables strong)
+	util low-exceptions tables strong)
   (files (opt usage)
          (opt sort)))
 
@@ -330,7 +347,7 @@
 	transforms
 	syntactic               ;static-value
 	packages
-	simple-signals
+	low-exceptions
 	features		;force-output
 	optimizer		;set-optimizer!
 	util)
@@ -343,25 +360,25 @@
 	transforms
 	packages
 	usages
-	simple-signals)
+	low-exceptions)
   (files (opt inline)))
 
 (define-structure strong (export strongly-connected-components)
-  (open scheme-level-2 define-record-types simple-signals)
+  (open scheme-level-2 define-record-types low-exceptions)
   (files (big strong))) ;!
 
+
 ;----------------
 ; Two basic structures needed to support the compiler.
 
 (define-structure tables general-tables-interface
   (open scheme-level-1
 	define-record-types
-	simple-signals
+	low-exceptions
 	features)    ; string-hash, make-immutable!
   (files (big general-table))
   (optimize auto-integrate))
 
 (define-structure filenames filenames-interface
-  (open scheme-level-1 simple-signals fluids cells)
+  (open scheme-level-1 low-exceptions fluids cells)
   (files (big filename)))
-
