@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 
 ; --------------------
@@ -9,10 +11,10 @@
 (define (with-exceptions thunk)
   (with-handler
        (lambda (c punt)
-	 (cond ((and (exception? c)
+	 (cond ((and (condition? c)
 		     (procedure? (get-exception-handler)))
 		(handle-exception-carefully c))
-	       ((interrupt? c)
+	       ((interrupt-condition? c)
 		(if (not (deal-with-interrupt c))
 		    (punt)))
 	       ;; ((vm-return? c)
