@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 
 ; Miniature evaluator.
@@ -45,7 +47,7 @@
 
 (define (initial-package name)
   (let ((probe (assq name *initial-bindings*)))
-    (if probe (cdr probe) (error "unbound" name))))
+    (if probe (cdr probe) (assertion-violation 'initial-package "unbound" name))))
 
 (define (define-initial name val)
   (let ((probe (assq name *initial-bindings*)))
