@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees
 
 ; This was a fun hack, but I didn't get much useful information out of
 ; it -- a profiler that only samples at points allowed by the VM's
@@ -24,8 +26,8 @@
 	(let ((foo (continuation-template k0)))
 	  (with-handler
 	      (lambda (c punt)
-		(if (and (interrupt? c)
-			 (eq? (interrupt-type c) interrupt/alarm))
+		(if (and (interrupt-condition? c)
+			 (eqv? (interrupt-source c) interrupt/alarm))
 		    (primitive-catch
 		      (lambda (k)
 			(record-profile-information! k foo table)
