@@ -1,10 +1,12 @@
-; Copyright (c) 1993-2005 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
 
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber, Marcus Crestani,
+; Robert Ransom, Marcel Turino, Ivan Shmakov, Harald Glab-Phlak
 
 ; Some interfaces.  Order of presentation is a bit random.
 
 (define-interface scheme-level-0-interface
-  (export ((if begin lambda letrec quote set!
+  (export ((if begin lambda letrec letrec* quote set!
 	       define define-syntax let-syntax letrec-syntax)
 	   :syntax)
 	  
@@ -35,7 +37,6 @@
 	  vector? make-vector vector-length vector-ref vector-set!
 
 	  ;; Unnecessarily primitive
-	  read-char peek-char write-char
 	  string=?
 	  vector
 	  assq
@@ -43,7 +44,7 @@
 	  ;; New in Revised^5 Scheme
 	  values call-with-values
 
-	  ;; Things aren't primitive at the VM level, but they have
+	  ;; Things that aren't primitive at the VM level, but have
 	  ;; to be defined using VM primitives.
 	  string-copy
 	  string->symbol
@@ -55,6 +56,8 @@
 (define-interface primitives-interface
   (export add-finalizer!
 	  call-external-value
+	  call-external-value-2
+	  channel-parameter
 	  checked-record-ref
 	  checked-record-set!
 	  collect			;,collect command
@@ -63,6 +66,7 @@
 	  continuation-set!
 	  continuation?
 	  copy-bytes!
+	  copy-string-chars!
 	  current-thread		;fluids threads
 	  double?
 	  eof-object                    ;i/o-internal re-exports this
@@ -70,6 +74,8 @@
 	  extended-number-ref
 	  extended-number-set!
 	  extended-number?
+	  new-external-event-uid
+	  unregister-external-event-uid!
 	  find-all			;externals, command-levels
 	  find-all-records		;threads
 	  immutable?
@@ -82,11 +88,16 @@
 	  make-weak-pointer
 	  memory-status			;interrupts
 	  os-error-message
+	  peek-byte
+	  peek-char
+	  read-byte
+	  read-char
 	  record
 	  record-length
 	  record-ref
 	  record-set!
 	  record?
+	  record-type<=?
 	  return-from-callback
 	  schedule-interrupt            ;interrupts re-exports this
 	  session-data			;channels
@@ -96,6 +107,7 @@
 	  set-interrupt-handlers!	;interrupts
 	  set-session-data!		;channels
 	  string-hash
+	  system-parameter
 	  template-length
 	  template-ref
 	  template-set!
@@ -105,7 +117,25 @@
 	  vm-extension
 	  wait
 	  weak-pointer-ref
-	  weak-pointer?))
+	  weak-pointer?
+	  make-transport-link-cell
+	  transport-link-cell?
+	  transport-link-cell-key
+	  transport-link-cell-value 
+	  set-transport-link-cell-value!
+	  transport-link-cell-tconc 
+	  set-transport-link-cell-tconc!
+	  transport-link-cell-next 
+	  set-transport-link-cell-next!
+	  write-byte
+	  write-char
+	  char->utf
+	  utf->char))
+
+(define-interface syntax-transformers-interface
+  (export make-explicit-renaming-transformer/4
+	  explicit-renaming-transformer/4?
+	  explicit-renaming-transformer/4-proc))
 
 (define-interface bitwise-interface
   (export arithmetic-shift
@@ -143,8 +173,8 @@
 (define-interface closures-interface
   (export closure?
 	  make-closure
-	  closure-env
-	  closure-template))
+	  closure-env set-closure-env!
+	  closure-template set-closure-template!))
 
 (define-interface byte-vectors-interface
   (export byte-vector?
@@ -153,6 +183,12 @@
 	  byte-vector-set!
 	  make-byte-vector
 
+	  ;; creates a byte-vector that will never be moved in a
+	  ;; garbage collection or raises an exception if the GC does
+	  ;; not support this feature.
+	  make-unmovable-byte-vector
+
+          byte-vector=?
 	  byte-vector))
 
 ; Same again, but with old names for compatibility.
@@ -183,6 +219,8 @@
   (export port?
 	  make-port
 	  port-handler
+	  port-text-codec-spec set-port-text-codec-spec!
+	  port-crlf?        set-port-crlf?!
 	  port-buffer       
 
 	  port-lock         set-port-lock!
@@ -190,12 +228,15 @@
 	  port-data         set-port-data!
 	  port-index        set-port-index!
 	  port-limit        set-port-limit!
+	  port-pending-cr?  set-port-pending-cr?!
 	  port-pending-eof? set-port-pending-eof?!
 
 	  provisional-port-status provisional-set-port-status!
 	  provisional-port-index  provisional-set-port-index!
 	  provisional-port-limit  provisional-set-port-limit!
 	  provisional-port-lock   provisional-set-port-lock!
+	  provisional-port-pending-cr?
+	  provisional-set-port-pending-cr?!
 	  provisional-port-pending-eof?
 	  provisional-set-port-pending-eof?!))
 
@@ -251,6 +292,7 @@
 	    with-new-proposal) :syntax)
 
 	  maybe-commit
+          proposal-active?
 	  remove-current-proposal!
 	  invalidate-current-proposal!
 
@@ -306,6 +348,11 @@
 	  ascii-limit
 	  ascii-whitespaces))
 
+(define-interface unicode-interface
+  (export scalar-value->char
+	  char->scalar-value
+	  scalar-value?))
+
 ; Level 1: The rest of Scheme except for I/O.
 
 (define-interface scheme-level-1-adds-interface
@@ -360,13 +407,15 @@
 	  last
 	  posq
 	  posv
-	  position
+	  posqual
 	  reduce
 	  sublist
 	  insert
 	  unspecific
+	  symbol-append
+          x->boolean
 
-	  (mvlet :syntax)))
+	  (receive :syntax)))
 
 ; Level 2 consists of harder things built on level 1.
 
@@ -378,14 +427,21 @@
 (define-interface record-types-interface
   (export make-record-type
 	  record-constructor
+	  record-standard-constructor
 	  record-accessor
 	  record-modifier
 	  record-predicate
 	  define-record-discloser
 	  define-record-resumer
 	  record-type?
+	  record-type<=?
 	  record-type-field-names
-	  record-type-name))
+	  record-type-name
+	  record-type-parent
+	  record-type-data
+	  record-type-size
+	  set-record-type-data!
+	  ))
 
 (define-interface define-record-types-interface
   (export (define-record-type :syntax)
@@ -395,28 +451,28 @@
   (export (define-generic :syntax)
 	  (define-method :syntax)
 	  (define-simple-type :syntax)
-	  :values
-	  :value
-	  :number
-	  :complex
-	  :real
-	  :rational
-	  :integer
-	  :exact-integer
-	  :boolean
-	  :symbol
-	  :char
-	  :null
-	  :pair
-	  :vector
-	  :string
-	  :procedure
-	  :input-port
-	  :output-port
-	  :eof-object
-	  :record
+	  <values>
+	  <value>
+	  <number>
+	  <complex>
+	  <real>
+	  <rational>
+	  <integer>
+	  <exact-integer>
+	  <boolean>
+	  <symbol>
+	  <char>
+	  <null>
+	  <pair>
+	  <vector>
+	  <string>
+	  <procedure>
+	  <input-port>
+	  <output-port>
+	  <eof-object>
+	  <record>
 	  :record-type
-	  :zero
+	  <zero>
 	  singleton
 	  disclose &disclose))
 
@@ -470,35 +526,85 @@
 
 (define :enumeration :syntax)
 
-(define-interface signals-interface
-  (export error warn syntax-error call-error note
-	  signal signal-condition
-	  make-condition))
+(define-interface low-exceptions-interface
+  (export ((error
+	    assertion-violation
+	    implementation-restriction-violation
+	    warning note
+	    syntax-violation)
+	   (proc (:value :string &rest :value) :values))))
+
+(define-interface low-exceptions-internal-interface
+  (export initialize-low-exception-procedures!))
 
 (define-interface handle-interface
   (export ignore-errors report-errors-as-warnings with-handler))
 
-(define-interface simple-conditions-interface
-  (export define-condition-type
+(define-interface conditions-interface
+  (export condition
+	  condition?
+	  simple-conditions
 	  condition-predicate
-	  decode-condition condition-stuff condition-type
-	  define-condition-decoder
-	  error? warning? note? syntax-error? call-error? read-error?
-	  interrupt?
+	  condition-accessor
+	  define-condition-type
+	  &condition
+	  &message
+	  make-message-condition
+	  message-condition?
+	  condition-message
+	  &warning
+	  make-warning
+	  warning?
+	  &serious
+	  make-serious-condition
+	  serious-condition?
+	  &error
+	  make-error
+	  error?
+	  &violation
+	  make-violation
+	  violation?
+	  &non-continuable
+	  make-noncontinuable-violation
+	  non-continuable-violation?
+	  &implementation-restriction
+	  make-implementation-restriction-violation
+	  implementation-restriction-violation?
+	  &lexical
+	  make-lexical-violation
+	  lexical-violation?
+	  &syntax
+	  make-syntax-violation
+	  syntax-violation?
+	  &undefined
+	  make-undefined-violation
+	  undefined-violation?
+	  &assertion
+	  make-assertion-violation
+	  assertion-violation?
+	  &irritants
+	  make-irritants-condition
+	  irritants-condition?
+	  condition-irritants
+	  &who
+	  make-who-condition
+	  who-condition?
+	  condition-who
 
-	  ;; Do these belong here?... not really.
-	  vm-exception-arguments
-	  vm-exception-reason
-	  vm-exception-opcode
-	  vm-exception?
-	  make-vm-exception
-
-	  i/o-error?
-	  i/o-error-status
-	  i/o-error-message
-	  i/o-error-operation
-	  i/o-error-arguments
-	  make-i/o-error))
+	  &vm-exception make-vm-exception vm-exception?
+	  vm-exception-opcode vm-exception-reason
+	  &os-error make-os-error os-error?
+	  os-error-code
+	  &i/o-error make-i/o-error i/o-error?
+	  &i/o-port-error make-i/o-port-error i/o-port-error? i/o-error-port
+	  &decoding-error make-decoding-error decoding-error?
+	  decoding-error-encoding-name
+	  decoding-error-bytes decoding-error-start
+	  &note make-note note?
+	  &interrupt make-interrupt-condition interrupt-condition?
+	  interrupt-source
+	  decode-condition
+	  ))
 
 (define-interface wind-interface
   (export call-with-current-continuation
@@ -508,32 +614,98 @@
   (export current-input-port current-output-port
 	  close-output-port close-input-port
 
+	  read-byte peek-byte write-byte byte-ready?
+	  read-char peek-char
 	  char-ready?
+	  write-char
 	  read-block write-block
 	  newline
-	  input-port-option		;read.scm
-	  output-port-option		;write.scm
 	  write-string			;write.scm
-	  initialize-i/o                ;init.scm
 	  with-current-ports
-	  initialize-i/o-handlers!      ;init.scm
-	  disclose-port
 	  current-error-port
 	  current-noise-port
 	  force-output			;xport.scm
+	  port-text-codec set-port-text-codec!
 	  output-port-ready?
 	  input-port?
 	  output-port?
 	  silently
 	  make-null-output-port))
 
+(define-interface text-codecs-interface
+  (export spec->text-codec text-codec->spec
+	  text-codec? make-text-codec
+	  text-codec-names
+	  text-codec-decode-char-proc
+	  text-codec-encode-char-proc
+
+	  (define-text-codec :syntax)
+	  find-text-codec
+
+	  null-text-codec
+	  us-ascii-codec
+	  latin-1-codec
+	  utf-8-codec
+	  utf-16le-codec utf-16be-codec
+	  utf-32le-codec utf-32be-codec))
+
+(define-interface encodings-interface
+  (export char-encoding-length
+	  string-encoding-length
+	  encode-char
+	  encode-string
+	  string->bytes-n
+	  string->bytes
+	  bytes-string-size
+	  decode-char
+	  decode-string
+	  bytes->string bytes->string-n
+	  
+	  char-encoding-length/utf-8
+	  string-encoding-length/utf-8
+	  encode-char/utf-8
+	  encode-string/utf-8
+	  string->utf-8-n
+	  string->utf-8
+	  bytes-string-size/utf-8
+	  decode-char/utf-8
+	  decode-string/utf-8
+	  utf-8->string utf-8->string-n
+
+	  (encoding-status :enumeration)
+	  (decoding-status :enumeration)))
+
+(define-interface os-strings-interface
+  (export os-string?
+	  make-os-string 
+	  string->os-string byte-vector->os-string x->os-string
+	  string->os-byte-vector x->os-byte-vector
+	  os-string->string os-string->byte-vector
+	  os-string-text-codec
+	  os-string=?
+	  call-with-os-string-text-codec
+	  current-os-string-text-codec))
+
 (define-interface i/o-internal-interface
-  (export make-buffered-input-port  make-unbuffered-input-port
+  (export input-port-option		;read.scm
+	  output-port-option		;write.scm
+
+	  initialize-i/o                ;init.scm
+	  initialize-i/o-handlers!      ;init.scm
+
+	  disclose-port
+
+	  make-buffered-input-port
 	  make-buffered-output-port make-unbuffered-output-port
 
 	  make-port-handler
+	  port-handler-discloser port-handler-close
+	  port-handler-byte port-handler-char port-handler-block
+	  port-handler-ready? port-handler-force
+
 	  make-buffered-input-port-handler
 	  make-buffered-output-port-handler
+	  make-unbuffered-output-port-handler
 	 
 	  ;port-handler-buffer-proc     ; extended-ports
 	  default-buffer-size
@@ -566,8 +738,7 @@
 	  channel-write
 
 	  initialize-channel-i/o!       ;scheduler
-	  waiting-for-i/o?              ;scheduler
-	  abort-unwanted-reads!		;scheduler
+	  zap-i/o-orphans!              ;root-scheduler
 
 	  ; call this with interrupts disabled
 	  wait-for-channel))		;big/socket.scm
@@ -617,12 +788,14 @@
 	  maybe-commit-and-block-on-queue
 	  maybe-commit-and-make-ready
 	  maybe-commit-no-interrupts
+	  threads-not-deadlocked-count
 	  spawn-on-scheduler spawn-on-root
-	  wait
+	  wait-for-event
 	  upcall propogate-upcall
 	  interrupt-thread
 	  kill-thread!
 	  terminate-thread!
+	  make-deadlock-condition deadlock-condition?
 
 	  thread-queue-empty?
 	  maybe-dequeue-thread!
@@ -640,29 +813,62 @@
 	  round-robin-event-handler
 
 	  make-counter            ; for thread counts
-	  counter-value
+	  counter-value set-counter!
           increment-counter!
           decrement-counter!))
 
 (define-interface queues-interface
-  (export make-queue enqueue! dequeue! maybe-dequeue! queue-empty? empty-queue!
-	  queue? queue->list list->queue queue-head queue-length
-	  delete-from-queue! on-queue?))
+  (export queue?
+
+          ;; Constructors.
+          make-queue
+          list->queue
+
+          ;; Queue operations.
+          queue-empty?
+          enqueue!
+          enqueue-many!
+          queue-head-or-thunk
+	  queue-head-or-value
+          queue-head
+          maybe-queue-head
+          dequeue-or-thunk!
+	  dequeue-or-value!
+          dequeue!
+          maybe-dequeue!
+          empty-queue!
+
+          ;; The following operations are *very* slow, and may be
+          ;; removed in a future revision.
+          queue->list
+          queue-length
+          on-queue?
+          delete-from-queue!))
+
+(define-interface queues-internal-interface
+  ;; Exported for testing.
+  (export list->queue-list))
 
 (define-interface exceptions-interface
-  (export with-exception-handler
-	  raise
-	  (guard :syntax)))
+  (compound-interface (export with-exception-handler
+			      raise raise-continuable
+			      (guard :syntax)
+			      (assert :syntax))
+		      low-exceptions-interface))
 
 (define-interface exceptions-internal-interface
   (export initialize-exceptions!
 	  really-signal-condition))
 
+(define-interface signal-conditions-interface
+  (export signal-condition))
+
 (define-interface vm-exceptions-interface
   (export define-vm-exception-handler
 	  initialize-vm-exceptions!
 	  extend-opcode!
-	  signal-vm-exception))
+	  signal-vm-exception
+	  vm-exception-reason->message))
 
 (define-interface interrupts-interface
   (export initialize-interrupts!	;init.scm
@@ -670,7 +876,8 @@
 	  no-interrupts
 	  ;reset-timer-interrupts!
 	  set-interrupt-handler!
-	  interrupt?
+	  get-interrupt-handler
+	  interrupt-condition?
 	  ;set-timer-interrupt!
 	  schedule-interrupt
 	  set-enabled-interrupts!	;command.scm
@@ -683,17 +890,26 @@
 	  call-before-heap-overflow!
 	  (interrupt :syntax)))
 
+(define-interface external-events-interface
+  (export initialize-external-events!	;init.scm
+	  zap-external-event-orphans!  ;root-scheduler.scm
+	  register-condvar-for-external-event!
+	  wait-for-external-event
+	  new-external-event-uid
+	  new-external-event
+	  unregister-external-event-uid!))
+
 (define-interface writing-interface
   (export write
 	  display
-	  display-type-name
 	  recurring-write))
 
 (define-interface reading-interface
   (export read
 	  define-sharp-macro		;command.scm
 	  reading-error
-	  gobble-line))
+	  gobble-line
+	  sub-read sub-read-carefully))
 
 ; Level 2: the harder stuff.
 ; Various primitives get numeric types and promoted to n-ary at this point.
@@ -708,6 +924,7 @@
 	  open-input-file open-output-file
 	  with-input-from-file with-output-to-file
 	  number->string string->number
+	  read-char peek-char write-char
 	  newline display write
 	  read))
 
@@ -733,7 +950,7 @@
 	  continuation-code
 	  continuation-template
 	  continuation?
-	  :continuation
+	  <continuation>
 
 	  vm-exception-continuation?
 	  vm-exception-continuation-exception
@@ -770,8 +987,10 @@
 	  file-name-directory
 	  file-name-nondirectory
 	  translate
+	  set-global-translation!
 	  set-translation!
-	  translations))
+	  make-translations with-translations
+	  current-translations))
 
 ; Things for the compiler.
 
@@ -780,15 +999,18 @@
 	  make-string-table
 	  make-symbol-table
 	  make-integer-table
+	  make-datum-table
 	  make-table-maker
 	  table?
           table-size
 	  table-ref
 	  table-set!
-	  table-walk
+	  table-walk table->entry-list
 	  make-table-immutable!
 
-	  string-hash
+          table-string-hash table-symbol-hash
+	  number-hash
+	  string-hash symbol-hash datum-hash
 	  default-hash-function))
 
 ;----------------
@@ -798,7 +1020,7 @@
   (export usual-transform))
 
 (define-interface meta-types-interface
-  (export same-type?
+  (export ; same-type? ; conflicts with `same-type?' from methods
 	  subtype?
 	  meet?
 	  join-type
@@ -807,7 +1029,7 @@
 	  syntax-type
 	  any-values-type
 	  any-arguments-type
-	  value-type
+	  value-type value-type?
 	  error-type
 
 	  make-some-values-type
@@ -879,37 +1101,40 @@
 
 	  make-name-table
 
+	  make-qualified
 	  qualified?
 	  qualified-parent-name
 	  qualified-symbol
 	  qualified-uid
-	  name->qualified
 
           desyntaxify
 	  ))
 
 (define-interface transforms-interface
-  (export make-transform
+  (export make-transform/macro
+	  make-transform/inline
 	  maybe-apply-macro-transform
 	  apply-inline-transform
 	  transform?
+	  transform-kind
 	  transform-type
 
 	  transform-env		; These are used to reify transforms.
 	  transform-aux-names
 	  transform-source
-	  transform-id))
+	  transform-id
+
+	  make-transform)) ; backwards compatibility
 
 (define-interface bindings-interface
   (export binding?
 	  make-binding
 	  binding-place
 	  set-binding-place!	;for package mutation, used in package.scm
-	  binding-static
+	  binding-static 
+	  set-binding-static! ; for letrec-syntax
 	  binding-type
-	  binding-path
 
-	  add-path
 	  clobber-binding!
 	  maybe-fix-place!
 	  forget-integration
@@ -923,16 +1148,17 @@
 
 (define-interface compiler-envs-interface
   (export make-compiler-env	; re-exported by syntactic
+	  compiler-env?
 	  lookup
-	  bind1 bind bindrec
+	  bind1 bind
 
 	  bind-source-file-name	; re-exported by syntactic
 	  source-file-name
 
-	  environment-macro-eval
-	  environment-define!
+	  comp-env-macro-eval
+	  comp-env-define!
 
-	  extract-package-from-environment))	; temporary
+	  extract-package-from-comp-env))	; temporary
 
 (define-interface syntactic-interface
   (export expand
@@ -940,9 +1166,28 @@
 	  scan-forms
 	  expand-scanned-form
 	  syntax?
+	  static-value
 	  make-compiler-env
 	  bind-source-file-name))
 
+(define-interface syntax-rules-data-interface
+  (export make-pattern-variable
+          pattern-variable?
+          pattern-variable-name
+          pattern-variable-rank
+
+          make-ellipsis-form
+          ellipsis-form?
+          ellipsis-form-body
+          ellipsis-form-vars
+
+          make-vector-marker
+          vector-marker?
+          vector-marker-contents))
+
+(define-interface syntax-rules-apply-interface
+  (export apply-rules))
+
 (define-interface nodes-interface
   (export make-node
 
@@ -958,6 +1203,8 @@
 	  force-node
 	  schemify
 
+	  name->qualified
+
 	  get-operator
 	  make-operator-table
 	  operator-name
@@ -969,6 +1216,33 @@
 	  operator-uid
 	  operator?
 	  operators-table		;config.scm comp-package.scm
+
+	  lambda-node?
+	  flat-lambda-node?
+	  name-node?
+	  call-node?
+	  literal-node?
+	  quote-node?
+	  define-node?
+	  loophole-node?
+
+	  operator/flat-lambda
+	  operator/lambda
+	  operator/set!
+	  operator/call
+	  operator/begin
+	  operator/name
+	  operator/letrec
+	  operator/letrec*
+	  operator/pure-letrec
+	  operator/literal
+	  operator/quote
+	  operator/unassigned
+	  operator/unspecific
+	  operator/define
+	  operator/define-syntax
+	  operator/primitive-procedure
+	  operator/structure-ref
 	  ))
 
 ;----------------
@@ -984,12 +1258,14 @@
 	  using-optional-label
 	  jump-instruction
 	  computed-goto-instruction
+	  stack-shuffle-instruction
 	  continuation-data
           lambda-protocol nary-lambda-protocol
           nary-primitive-protocol continuation-protocol
           cwv-continuation-protocol
           make-dispatch-protocol
-	  make-label
+	  make-label label?
+	  label-reference
 	  note-environment
 	  note-source-code
 	  segment->cv segment->template
@@ -1023,6 +1299,7 @@
 	  template-offset
 	  environment-offset
 	  depth-check!
+	  index->offset
 	  literal->index
 	  binding->index))
 
@@ -1043,6 +1320,7 @@
 	  debug-data-env-shape
 	  debug-data-name
 	  debug-data-parent
+	  debug-data-jump-back-dests
 	  debug-data-source
 	  debug-data-uid
 	  debug-data?
@@ -1052,6 +1330,7 @@
   (export make-debug-data
 	  set-debug-data-source!
 	  set-debug-data-env-maps!
+	  set-debug-data-jump-back-dests!
 	  debug-flag-names		; keep and flush commands
 	  debug-flag-accessor
 	  debug-flag-modifier
@@ -1104,8 +1383,7 @@
 	  make-new-location		;ctop.scm
 	  structure-package
 	  note-structure-name!
-	  (:package :type)
-	  (:structure :type)))		;for (define-method ...)'s
+	  (:package :type)))
 
 (define-interface packages-internal-interface
   (export package-loaded?		;env/load-package.scm
@@ -1116,6 +1394,7 @@
 	  location-info-table		;debuginfo, disclosers
 	  package-definition
 	  package-unstable?		;env/pacman.scm
+	  environment-stable?           ;comp/schemify.scm
 	  package-integrate?		;env/debug.scm
 	  package-add-static!		;opt/analyze.scm
 	  package-refine-type!		;opt/usage.scm
@@ -1125,6 +1404,7 @@
 	  package-accesses
 	  package-clauses
 	  package-file-name
+	  package-reader set-package-reader!
 	  package-opens
 	  set-package-integrate?!
 	  structure-name
@@ -1192,13 +1472,16 @@
 	  environment-ref
 	  environment-set!
 	  interaction-environment
-	  make-reflective-tower
+	  make-syntactic-tower
+	  make-reflective-tower ; backwards compatibility for PreScheme compiler
 	  scheme-report-environment
 	  null-environment
 	  set-interaction-environment!
 	  set-scheme-report-environment!
 	  with-interaction-environment
-	  set-reflective-tower-maker!))
+	  set-syntactic-tower-maker!
+	  set-reflective-tower-maker! ; backwards compatibility for PreScheme compiler
+	  set-reader!))
 
 (define-interface defpackage-interface
   (export ((def			        ;Formerly define-structure
@@ -1207,8 +1490,10 @@
 	    define-structure
 	    define-module
 	    define-syntax
-	    define-reflective-tower-maker
-	    export-reflective-tower-maker
+	    define-reader
+	    define-syntactic-tower-maker
+	    export-syntactic-tower-maker
+	    export-reflective-tower-maker ; backwards compatibility for PreScheme compiler
 	    compound-interface
 	    modify subset with-prefix
 	    export
@@ -1248,10 +1533,9 @@
 	  ; eval-scanned-forms
 	  ))
 
-(define-interface display-conditions-interface
-  (export display-condition		;command.scm
-	  &disclose-condition      	;env/disclosers.scm
-	  limited-write))
+(define-interface load-filenames-interface
+  (export with-load-filename
+	  current-load-filename))
 
 ; Bindings needed by the form composed by REIFY-STRUCTURES.
 
@@ -1272,3 +1556,4 @@
 	  ))
 
 ;(define-interface command-interface ...)  -- moved to more-interfaces.scm
+
