@@ -1,4 +1,8 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber, Michael Zabka,
+; Robert Ransom, Marcus Crestani, Ivan Shmakov, Martin Gasbichler,
+; David van Horn, Harald Glab-Phlak
 
 
 ; Meta-modules: the big picture.
@@ -41,10 +45,10 @@
 			     (features features-interface)
 			     (records records-interface)
 			     (record-types record-types-interface)
-			     (simple-signals signals-interface))
+			     (low-exceptions low-exceptions-interface))
 	   ;; Assumes use of FLATLOAD.  The implementations of these
 	   ;; structures will become available via some miracle, e.g.
-	   ;; a command ",open simple-signals ... code-vectors" or an
+	   ;; a command ",open low-exceptions ... code-vectors" or an
 	   ;; explicit LOAD of something.  Cf. the rule for
 	   ;; link/linker.image in the Makefile.
 	   )))
@@ -195,9 +199,9 @@
 				run-time-structures
 				compiler-structures))
   (files ;; more-interfaces, when not flatloading
-         env-packages
 	 ;; (sort interfaces), when not flatloading
 	 (sort packages)
+         env-packages
 	 more-packages))
 
 
@@ -227,8 +231,7 @@
 	    bitwise
 	    code-vectors
 	    features
-	    records
-	    simple-signals)
+	    records)
 	   :structure)))
 
 (define-interface low-structures-interface
@@ -240,11 +243,10 @@
 	    code-vectors
 	    features
 	    records
-	    simple-signals
 	    cells
 	    channels
 	    closures
-	    code-quote
+	    code-quotation
 	    escapes
 	    locations
 	    loopholes
@@ -254,10 +256,12 @@
 	    low-proposals
 	    scheme-level-0
 	    shared-bindings
+	    signal-conditions
 	    silly
 	    source-file-names
 	    structure-refs
 	    debug-messages
+	    syntax-transformers
 	    unicode
 	    vm-exposure
 	    write-images)
@@ -290,7 +294,7 @@
 
 (define-interface run-time-internals-structures-interface
   (export ((channel-ports
-	    simple-conditions
+	    conditions
 	    continuations
 	    ;; escapes
 	    exceptions
@@ -307,10 +311,12 @@
 	    more-types
 	    number-i/o
 	    ;; primitives
+	    queues-internal
 	    reading
 	    records-internal
 	    root-scheduler
 	    session-data
+	    syntax-rules-apply
 	    threads-internal
 	    vm-exceptions
 	    usual-resumer
@@ -359,6 +365,7 @@
 
 (define-interface initial-structures-interface
   (export ((environments
+	    load-filenames
 	    evaluation
 	    ensures-loaded
 	    ;; for-reification is in there, but shouldn't get reified.
@@ -399,8 +406,8 @@
 	  mini-eval
 	  mini-environments))
 
-; Must list all the packages defined in this file that are to be
-; visible in the command processor's config package.
+; Must list all the packages in the various package files that are to
+; be visible in the command processor's config package.
 
 (define-interface more-structures-interface
   (export ((more-structures
@@ -413,10 +420,13 @@
 	    bignums ratnums recnums floatnums
 	    build
 	    callback
+	    code-quote ; compatibility to earlier versions
 	    command-levels
 	    command-processor
 	    command-state
+	    usual-commands
 	    compact-tables
+	    constant-tables
 	    conditions
 	    c-system-function
 	    debugging
@@ -429,7 +439,7 @@
 	    dump/restore
 	    dynamic-externals
 	    enum-case
-	    enum-sets
+	    enum-sets enum-sets-internal
 	    extended-numbers
 	    extended-ports
 	    externals
@@ -437,7 +447,6 @@
 	    finite-types
 	    floatnums
 	    formats
-	    i/o-conditions
 	    inspector
 	    inspector-internal
 	    inversion-lists
@@ -449,15 +458,24 @@
 	    mask-types
 	    mvlet
 	    nondeterminism
+	    net-addresses
+	    net-sockets
+            os-time
 	    package-commands-internal
 	    package-mutation
-            parse-bytecode
+	    parse-bytecode
 	    placeholders
 	    pp
-	    ;profile
+	    previews
+	    profiler
+	    profile-commands
+	    profiler-instrumentation
+	    profiler-internals
 	    queues
 	    shared-objects
+	    tconc-queues
 	    time
+	    tlc-tables
 	    random
 	    receiving
 	    reduce
@@ -473,18 +491,19 @@
 	    vector-merge-sort
 	    vector-heap-sort
 	    vector-insertion-sort
+	    vector-quick-sort vector-quick-sort3
 	    sorting
 	    sort
 
 	    sparse-vectors
 	    reinitializers
+	    signals
 	    spatial
 	    strong
 	    text-codec-utils
 	    traverse
 	    udp-sockets
 	    unicode-normalizations
-	    r6rs-unicode
 	    value-pipes
 	    variable-argument-lists
 
@@ -513,14 +532,42 @@
 	    make-rendezvous
 	    trans-ids
 
+	    r5rs
+
+	    ; R6RS packages
+
+	    r6rs-base-comparisons
+	    r6rs-bitwise
+	    r6rs-conditions
+	    r6rs-records-procedural
+	    r6rs-records-inspection
+	    r6rs-records-internal
+	    r6rs-records-commands
+	    r6rs-records-syntactic
+	    r6rs-records-syntactic-internal
+	    r6rs-unicode
+	    r6rs-lists
+	    r6rs-enums
+	    r6rs-sorting
+	    r6rs-reader
+	    r6rs-reader-command
+	    r6rs-reader-internals
+            r6rs-equal
+            r6rs-control
+	    r6rs-bytevectors
+	    r6rs-hashtables
+
 	    ; POSIX packages (see scheme/posix/packages.scm)
 	    posix-files
 	    posix-time
 	    posix-users
 	    posix-process-data
+	    posix-platform-names
 	    posix-processes
 	    posix-regexps
 	    posix-i/o
+	    posix-errnos
+	    posix-syslog
 	    regexps regexps-internal
 	    posix
 
@@ -528,11 +575,14 @@
 	    srfi-1 srfi-2 srfi-4 srfi-5 srfi-6 srfi-7 srfi-8 srfi-9
 	    srfi-11 srfi-13 srfi-14 srfi-16 srfi-17 srfi-19
 	    srfi-23 srfi-25 srfi-26 srfi-27 srfi-28
-	    srfi-31 srfi-34 srfi-35 srfi-36 srfi-37
+	    srfi-31 srfi-34 srfi-37
 	    srfi-39 srfi-40 srfi-42 srfi-43 srfi-45
-            srfi-60 srfi-61 srfi-63 srfi-66 srfi-67
-	    srfi-71 srfi-74 srfi-78
+            srfi-60 srfi-61 srfi-62 srfi-63 srfi-66 srfi-67
+	    srfi-71 srfi-74 srfi-78 srfi-95
+
+            libscheme48
 	    test-suites
+	    matchers
 	    )
 	   :structure)
 	  ((define-signature define-package) :syntax)))
