@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 
 ; Stuff in Pre-Scheme that is not in Scheme.
@@ -129,10 +131,3 @@
 
 (define current-error-port current-output-port)
 
-; RECEIVE (from big-scheme)
-
-(define-syntax receive
-  (syntax-rules ()
-    ((receive ?vars ?producer . ?body)
-     (call-with-values (lambda () ?producer)
-		       (lambda ?vars . ?body)))))
