@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees
 
 ; Condition variables (cells for which readers block until the next write).
 ;
@@ -30,8 +32,8 @@
 			   #f
 			   (car id-option))))
 
-(define (maybe-commit-and-wait-for-condvar condvar)
-  (maybe-commit-and-block-on-queue (condvar-queue condvar)))
+(define (maybe-commit-and-wait-for-condvar condvar . maybe-deadlock?)
+  (apply maybe-commit-and-block-on-queue (condvar-queue condvar) maybe-deadlock?))
 
 (define (maybe-commit-and-set-condvar! condvar value)
   (set-condvar-value! condvar value)
