@@ -1,5 +1,7 @@
 ; -*- Mode: Scheme; Syntax: Scheme; Package: Scheme; -*-
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; Continuations
 
@@ -91,9 +93,9 @@
 	    exception-continuation-cells
 	    0))))
 
-(define-simple-type :continuation (:value) continuation?)
+(define-simple-type <continuation> (<value>) continuation?)
 
-(define-method &disclose ((obj :continuation))
+(define-method &disclose ((obj <continuation>))
   (list (if (vm-exception-continuation? obj)
 	    'vm-exception-continuation
 	    'continuation)
