@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ; Current input, output, error, and noise ports.
 
@@ -63,10 +65,14 @@
 (define (output-port-option port-option)
   (cond ((null? port-option) (current-output-port))
 	((null? (cdr port-option)) (car port-option))
-	(else (error "write-mumble: too many arguments" port-option))))
+	(else
+	 (assertion-violation 'write-mumble
+			      "too many arguments" port-option))))
 
 (define (input-port-option port-option)
   (cond ((null? port-option) (current-input-port))
 	((null? (cdr port-option)) (car port-option))
-	(else (error "read-mumble: too many arguments" port-option))))
+	(else
+	 (assertion-violation 'read-mumble
+			      "read-mumble: too many arguments" port-option))))
 
