@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Alan Bawden
 
 
 ; Simplest rational within an interval.  Copied from IEEE P1178/D4 nimpl.tex.
@@ -23,7 +25,9 @@
              (+ 1 fx)))))
   ;; Do some juggling to satisfy preconditions of simplest-rational-internal.
   (cond ((not (< x y))
-         (if (rational? x) x (error "(rationalize <irrational> 0)" x)))
+         (if (rational? x)
+	     x 
+	     (assertion-violation 'rationalize "(rationalize <irrational> 0)" x)))
         ((positive? x)
          (simplest-rational-internal x y))
         ((negative? y)
