@@ -1,28 +1,24 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber, Robert Ransom
 
 
 ; Low-level things that rely on the fact that we're running under the
 ; Scheme 48 VM.
 
-; Historical kludge; ASCII is a misnomer (as it covers only [0, 127])---
-; we really mean Latin-1.
-
 (define (char->ascii c)
   (let ((scalar-value (char->scalar-value c)))
     (if (>= scalar-value ascii-limit)
-	(signal-condition
-	 (cons 'call-error
-	       (cons "not an ASCII character"
-		     (cons char->ascii (cons c '()))))))
+	(assertion-violation 'char->ascii
+			     "not an ASCII character"
+			     c))
     scalar-value))
 
 (define (ascii->char x)
   (if (or (>= x ascii-limit) (< x 0))
-      (signal-condition
-       (cons 'call-error
-	     (cons"not an ASCII code"
-		  (cons ascii->char
-			(cons x '()))))))
+      (assertion-violation 'ascii->char
+			   "not an ASCII code"
+			   x))
   (scalar-value->char x))
 
 (define (char->integer c) (char->scalar-value c))
@@ -158,7 +154,18 @@
 (define (undefine-exported-binding name)
   (undefine-shared-binding name #f))
 
-; This really shouldn't be here, but I don't know where else to put it.
+; These really shouldn't be here, but we don't know where else to put them.
+
+(define (byte-vector=? b1 b2)
+  (let ((size-1 (byte-vector-length b1))
+	(size-2 (byte-vector-length b2)))
+    (and (= size-1 size-2)
+	 (let loop ((i 0))
+	   (cond
+	    ((>= i size-1) #t)
+	    ((= (byte-vector-ref b1 i) (byte-vector-ref b2 i))
+	     (loop (+ 1 i)))
+	    (else #f))))))
 
 (define (byte-vector . l)
   (let ((v (make-byte-vector (secret-length l 0) 0)))
@@ -187,9 +194,9 @@
 		     message
 		     undumpable)
     (if (vector-ref undumpable 0)
-	(signal 'error
-		"undumpable records written in image"
-		(vector-prefix->list undumpable)))))
+	(assertion-violation 'write-image
+			     "undumpable records written in image"
+			     (vector-prefix->list undumpable)))))
 
 ; Return a list containing the non-#F values at the beginning of VECTOR.
 
