@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber
 
 ;;;; number->string and string->number
 
@@ -17,19 +19,19 @@
 		      (exact? radix)
 		      (< 0 radix))))
 	(real-number->string number radix)
-	(apply call-error
-	       "invalid argument"
+	(apply assertion-violation
 	       'number->string
+	       "invalid argument"
 	       number
 	       maybe-radix))))
 
 (define-method &number->string (n radix)
-  (call-error "invalid argument"
-	      'number->string
-	      n
-	      radix))
+  (assertion-violation 'number->string
+		       "invalid argument"
+		       n
+		       radix))
 
-(define-method &number->string ((n :exact-integer) radix)
+(define-method &number->string ((n <exact-integer>) radix)
   (integer->string n radix))
 
 (define integer->string    ;Won't necessarily work if n is inexact
@@ -67,8 +69,8 @@
 
 (define (string->number string . options)
   (if (not (string? string))
-      (apply call-error "invalid argument"
-	     'string->number
+      (apply assertion-violation 'string->number
+	     "invalid argument"
 	     string options))
   (let* ((radix (cond ((null? options) 10)
 		      ((null? (cdr options)) (car options))
@@ -77,9 +79,8 @@
 	 (radix (case radix
 		  ((2 8 10 16) radix)
 		  ((b) 2) ((o) 8) ((d) 10) ((x) 16)    ;R3RS only?
-		  (else (call-error "invalid radix"
-				    'string->number
-				    string radix))))
+		  (else (assertion-violation 'string->number
+					     "invalid radix" string radix))))
 	 (len (string-length string)))
     (let loop ((pos 0) (exactness? #f) (exact? #t) (radix? #f) (radix radix))
       (cond ((>= pos len)
@@ -116,8 +117,9 @@
 		      (cond ((>= pos len) #t) ;exact
 			    ((char=? (string-ref string pos) #\.)
 			     (if (not (= radix 10))
-				 (warn "non-base-10 number has decimal point"
-				       string))
+				 (warning 'string->number
+					  "non-base-10 number has decimal point"
+					  string))
 			     #f)	;inexact
 			    ((char=? (string-ref string pos) #\#)
 			     #f)
@@ -138,7 +140,7 @@
 
 ; Read exact integers
 
-(define-simple-type :integer-string (:string)
+(define-simple-type <integer-string> (<string>)
   (lambda (s)
     (and (string? s)
 	 (let loop ((i (- (string-length s) 1)))
@@ -154,7 +156,7 @@
 			       (or (char=? c #\+) (or (char=? c #\-)))))
 		      (loop (- i 1)))))))))
 
-(define-method &really-string->number ((string :integer-string) radix xact?)
+(define-method &really-string->number ((string <integer-string>) radix xact?)
   (let ((n (string->integer string radix)))
     (if n
 	(set-exactness n xact?)
