@@ -1,13 +1,12 @@
-; Copyright (c) 1993-2005 by Richard Kelsey and Jonathan Rees. See file COPYING.
-
-
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
 
+; Authors: Richard Kelsey, Jonathan Rees
 
 (define (make-population)
   (list '<population>))
 
 (define (add-to-population! x pop)
-  (if (not x) (error "can't put #f in a population"))
+  (if (not x) (assertion-violation 'add-to-population! "can't put #f in a population"))
   (if (not (weak-memq x (cdr pop)))
       (set-cdr! pop (cons (make-weak-pointer x) (cdr pop)))))
 
