@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Robert Ransom
 
 
 ; Higher-level proposal stuff.
@@ -96,6 +98,11 @@
 (define (remove-current-proposal!)
   (set-current-proposal! #f))
 
+; Useful for detecting that a proposal should be got rid of.
+
+(define (proposal-active?)
+  (x->boolean (current-proposal)))
+
 ; For use when an inconsistency has been detected.  The SET-CAR! ensures that
 ; the earlier PROVISIONAL-CAR will fail.
 
