@@ -1,4 +1,7 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber, 
+; Suresh Jagannathan, Henry Ceijtin
 
 ; The root scheduler.
 ;
@@ -16,7 +19,8 @@
 					 quantum
 					 abort)
 				      (lambda ()
-					(abort-unwanted-reads!)
+					(zap-i/o-orphans!)
+					(zap-external-event-orphans!)
 					(spawn-output-forcers #t)
 					(wake-some-threads))
 				      housekeeping-quantum)
@@ -49,8 +53,8 @@
 
 (define (root-handler condition next-handler)
   (let ((out (current-error-port)))
-    (cond ((error? condition)
-	   (display "Error while running root thread, thread killed: " out)
+    (cond ((serious-condition? condition)
+	   (display "Serious problem while running root thread, thread killed: " out)
 	   (display (current-thread) out)
 	   (newline out)
 	   (cheap-display-condition condition out)
@@ -64,21 +68,26 @@
 (define (cheap-display-condition condition out)
   (call-with-values
       (lambda () (decode-condition condition))
-    (lambda (type stuff)
+    (lambda (type who message stuff)
       (display (case type
 		 ((error) "Error")
+		 ((assertion-violation) "Assertion violation")
+		 ((serious) "Serious problem")
 		 ((vm-exception) "VM Exception")
 		 ((warning) "Warning")
 		 (else type))
 	       out)
       (display ": " out)
-      (display (car stuff) out)
+      (display " [" out)
+      (display who out)
+      (display "]" out)
+      (display message out)
       (newline out)
       (for-each (lambda (irritant)
 		  (display "    " out)
 		  (display irritant out)
 		  (newline out))
-		(cdr stuff)))))
+		stuff))))
 	 
 ; Upcall token
 
@@ -102,8 +111,7 @@
 	      (set-enabled-interrupts! all-interrupts)
 	      #t)
 	     ((or time-until-wakeup
-		  (waiting-for-i/o?)
-		  (waiting-for-external-events?))
+		  (> threads-not-deadlocked-count 0))
 	      (do-some-waiting time-until-wakeup)
 	      (set-enabled-interrupts! all-interrupts)
 	      (root-wait))
@@ -132,7 +140,7 @@
 				   one-minute-of-milliseconds)
 			 one-year-of-minutes)	; stick with fixnums
 		    #t))))
-   primitive-wait))
+   wait))
 
 (define one-minute-of-milliseconds (* 1000 60))
 
