@@ -1,4 +1,7 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber, Suresh Jagannathan, 
+; Henry Ceijtin
 
 ; A parameterized scheduler.
 
@@ -104,10 +107,10 @@
 	  ((no-event)
 	   (values))
 	  (else
-	   (error "unhandled event"
-		  (cons (enumerand->name event event-type)
-			event-data)
-		  event-handler)))))
+	   (assertion-violation 'asynchronous-event-handler "unhandled event"
+				(cons (enumerand->name event event-type)
+				      event-data)
+				event-handler)))))
 
   (define (next-thread)
     (if (queue-empty? runnable)
