@@ -112,10 +112,11 @@
 (define (shift-carefully value+tag count+tag succ fail)
   (let ((value (extract-fixnum value+tag))
 	(count (extract-fixnum count+tag)))
-    (if (< count 0)
+    (if (<= count 0)
 	(goto succ (arithmetic-shift-right value (- 0 count)))
 	(let ((result (shift-left value count)))
-	  (if (and (= value (arithmetic-shift-right result count))
+	  (if (and (< count bits-per-fixnum)
+		   (= value (arithmetic-shift-right result count))
 		   (if (>= value 0)
 		       (>= result 0)
 		       (< result 0)))
