@@ -1,5 +1,7 @@
 ; -*- Mode: Scheme; Syntax: Scheme; Package: Scheme; -*-
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Marcus Crestani, Mike Sperber
 
 ;;;; Data representations
 
@@ -193,7 +195,7 @@
 
 (define true          (make-immediate (enum imm true) 0))
 (define false         (make-immediate (enum imm false) 0))
-(define eof-object    (make-immediate (enum imm eof)  0))
+(define vm-eof-object (make-immediate (enum imm eof)  0)) ; distinguish from RTS's idea of this
 (define null          (make-immediate (enum imm null) 0))
 (define unspecific-value  (make-immediate (enum imm unspecific) 0))
 (define quiescent         (make-immediate (enum imm undefined) 0))
@@ -226,10 +228,10 @@
   (ascii->char (immediate-info d)))
 
 ; new:
-(define (scalar-value->char c)
+(define (scalar-value->vm-char c)
   (make-immediate (enum imm char) c))
 
-(define (char->scalar-value d)
+(define (vm-char->scalar-value d)
   (assert (vm-char? d))
   (immediate-info d))
 
