@@ -1,4 +1,7 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Marcus Crestani, David Frese,
+; Mike Sperber, Martin Gasbichler
 
 ; Pre-Allocation
 ;
@@ -75,29 +78,35 @@
 ; objects.  These may trigger a GC and will return false if insufficient
 ; space is available after the GC.
 
-(define (maybe-make-b-vector+gc type len)
-  (let ((addr (s48-allocate-untraced+gc (+ len
-					   (cells->bytes stob-overhead)))))
+(define (maybe-make-stob type len-in-bytes allocator)
+  (let ((addr (allocator (+ len-in-bytes (cells->bytes stob-overhead)))))
     (if (null-address? addr)
 	false
-	(initialize-stob addr type len))))
+	(initialize-stob addr type len-in-bytes))))
+
+(define (maybe-make-b-vector+gc type len)
+  (maybe-make-stob type len s48-allocate-untraced+gc))
+
+;; Hint: consider looking at s48-gc-can-allocate-unmovable? 
+;; before calling maybe-make-unmovable-b-vector+gc because the
+;; twospace-gc version of s48-allocate-(un)traced-unmovable+gc will stop
+;; the program with an error message.
+(define (maybe-make-unmovable-b-vector+gc type len)
+  (maybe-make-stob type len s48-allocate-untraced-unmovable+gc))
 
 (define (maybe-make-d-vector+gc type len)
-  (let* ((len (cells->bytes len))
-	 (addr (s48-allocate-traced+gc (+ len
-					  (cells->bytes stob-overhead)))))
-    (if (null-address? addr)
-	false
-	(initialize-stob addr type len))))
+  (maybe-make-stob type (cells->bytes len) s48-allocate-traced+gc))
 
-(define (make-weak-pointer init weak-pointer-size)
-  (let* ((addr (s48-allocate-weak+gc (cells->bytes weak-pointer-size)))
-	 (weak-pointer (initialize-stob addr 
-					(enum stob weak-pointer) 
-					(cells->bytes (- weak-pointer-size 1)))))
-    (d-vector-init! weak-pointer 0 init)
-    weak-pointer))
+(define (maybe-make-unmovable-d-vector+gc type len)
+  (maybe-make-stob type (cells->bytes len) s48-allocate-traced-unmovable+gc))
 
+; we can't go through ensure-space, as weak pointers might live in
+; a separate area
+(define (make-weak-pointer weak-pointer-size)
+  (let ((addr (s48-allocate-weak+gc (cells->bytes weak-pointer-size))))
+    (initialize-stob addr 
+		     (enum stob weak-pointer) 
+		     (cells->bytes (- weak-pointer-size 1)))))
 
 ; Add the header to a stob and add the tag to the address.
 
