@@ -1,4 +1,7 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Martin Gasbichler, David Frese,
+; Marcus Crestani, Mike Sperber
 
 (define-interface vm-utilities-interface
   (export adjoin-bits low-bits high-bits unsigned-high-bits
@@ -59,6 +62,8 @@
 (define-interface stob-interface
   (export make-d-vector make-b-vector
 	  maybe-make-d-vector+gc maybe-make-b-vector+gc
+	  maybe-make-unmovable-d-vector+gc
+	  maybe-make-unmovable-b-vector+gc
           d-vector-length d-vector-ref d-vector-init! d-vector-set!
 	  b-vector-length b-vector-ref b-vector-set!
 	  max-stob-size-in-cells
@@ -80,7 +85,14 @@
 	  s48-allocate-weak+gc
 	  s48-allocate-traced+gc
 	  s48-allocate-untraced+gc
+
+	  s48-gc-can-allocate-unmovable? ;; is a function due to a limitation (bug?) of pre-scheme
+	  s48-allocate-traced-unmovable+gc
+	  s48-allocate-untraced-unmovable+gc
+	  s48-unmovable?
 	  s48-allocate-stob
+	  s48-allocate-weak-stob
+	  s48-allocate-unmovable-stob
 	  
 	  s48-forbid-gc!
 	  s48-allow-gc!
@@ -211,6 +223,12 @@
 	  cell? cell-size make-cell cell-ref cell-set!
 	  weak-pointer? weak-pointer-size make-weak-pointer weak-pointer-ref
 
+	  transport-link-cell? make-transport-link-cell
+	  transport-link-cell-key
+	  transport-link-cell-value set-transport-link-cell-value!
+	  transport-link-cell-tconc set-transport-link-cell-tconc!
+	  transport-link-cell-next set-transport-link-cell-next!
+
 	  shared-binding? shared-binding-size make-shared-binding
 	  shared-binding-name shared-binding-is-import?
 	  shared-binding-ref shared-binding-set!
@@ -283,6 +301,13 @@
 	  ensure-space
 	  ))
 
+(define-interface vm-records-interface
+  (export typed-record?
+	  record-has-type?
+	  possibly-record-type?
+	  record-type-name
+	  record-type<=?))
+
 (define-interface vmio-interface
   (export initialize-i/o-system+gc
 
@@ -338,6 +363,7 @@
 	  push-native-exception-continuation!
 	  pop-continuation-from-stack
 	  pop-exception-data
+          pop-native-exception-data
 
 	  set-current-continuation!
 	  current-continuation-size
@@ -375,6 +401,7 @@
   (export extended-vm
 
 	  external-call
+	  external-call-2
 
 	  real-time
 	  run-time
@@ -419,8 +446,10 @@
 	  shared-ref
 	  (shared-set! :syntax)
 
-	  raise-argument-type-error
-	  raise-range-error
+	  argument-type-violation
+	  range-violation
+
+	  trace-external-calls
 	  ))
 
 (define-interface event-interface
@@ -464,8 +493,8 @@
 
 (define external-events-interface
   (export initialize-external-events
-	  s48-permanent-external-event-uid
-	  s48-external-event-uid s48-unregister-external-event-uid
+	  permanent-external-event-uid
+	  external-event-uid unregister-external-event-uid!
 	  s48-external-event-ready?/unsafe s48-external-event-pending?/unsafe
 	  s48-note-external-event!/unsafe
 	  s48-dequeue-external-event!/unsafe))
@@ -541,7 +570,7 @@
 	  push-exception-setup!
 
 	  any-> string-> boolean-> fixnum-> vm-integer-> char-> char-scalar-value->
-	  vector-> code-vector-> 
+	  vector-> record-type-> code-vector-> 
 	  input-type no-coercion
 	  
 	  no-result
@@ -585,6 +614,7 @@
 	  *last-code-called*
 	  *native-exception-cont*
 	  *val*
+          s48-*nc-template*
 	  ))
 
 ; What the external world can call.  Because of C's flat namespace we have
@@ -611,7 +641,6 @@
           s48-os-signal-pending
 	  s48-reset-interrupts!
 
-	  s48-external-event-uid s48-permanent-external-event-uid s48-unregister-external-event-uid
 	  s48-external-event-pending?/unsafe s48-external-event-ready?/unsafe
 	  s48-note-external-event!/unsafe
 	  s48-dequeue-external-event!/unsafe
@@ -655,6 +684,7 @@
 	  *stack*
 	  *last-code-called*
 	  *native-exception-cont*
+          s48-*nc-template*
 	  s48-*stack-limit*
 	  s48-*native-protocol*
 	  s48-set-native-protocol!
@@ -671,6 +701,7 @@
 	  s48-integer-or-floanum->=
           s48-integer-remainder
           s48-integer-quotient
+          s48-integer-divide
 	  s48-integer-bitwise-not
 	  s48-integer-bit-count
 	  s48-integer-bitwise-and
@@ -693,6 +724,19 @@
 	  s48-enter-string-utf-8-n
 	  s48-copy-string-to-utf-8
 	  s48-copy-string-to-utf-8-n
+
+	  s48-string-utf-16be-length
+	  s48-string-utf-16be-length-n
+	  s48-enter-string-utf-16be/
+	  s48-enter-string-utf-16be-n/
+	  s48-copy-string-to-utf-16be/
+	  s48-copy-string-to-utf-16be-n/
+	  s48-string-utf-16le-length
+	  s48-string-utf-16le-length-n
+	  s48-enter-string-utf-16le/
+	  s48-enter-string-utf-16le-n/
+	  s48-copy-string-to-utf-16le/
+	  s48-copy-string-to-utf-16le-n/
 	  ))
 
 ; Reading and writing images
