@@ -1,4 +1,6 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Martin Gasbichler, Mike Sperber
 
 ; Code to handle the calling and return protocols.
 
@@ -17,7 +19,32 @@
 (define-opcode tail-call
   (let ((stack-arg-count (code-byte 0)))
     (move-args-above-cont! stack-arg-count)
-    (goto do-call (code-byte 0))))
+    (goto do-call stack-arg-count)))
+
+(define-opcode known-call
+  (let ((stack-arg-count (code-byte 2))
+	(skip (if (= 0 (code-byte 3)) 2 4)))
+    (make-continuation-on-stack (address+ *code-pointer* (code-offset 0))
+				stack-arg-count)
+    (goto do-known-call stack-arg-count skip)))
+
+(define-opcode known-tail-call
+  (let ((stack-arg-count (code-byte 0))
+	(skip (if (= 0 (code-byte 3)) 2 4)))
+    (move-args-above-cont! stack-arg-count)
+    (goto do-known-call stack-arg-count skip)))
+
+; questionable
+(define-opcode big-known-call
+  (let ((stack-arg-count (code-offset 2))
+	(skip (if (= 0 (code-byte 4)) 2 4)))
+    (maybe-make-continuation stack-arg-count)
+    (goto do-known-call stack-arg-count skip)))
+
+(define (do-known-call stack-arg-count skip)
+  (let* ((template (closure-template *val*))
+	 (code (template-code template)))
+    (goto run-body-with-default-space code skip template)))
 
 (define (do-call stack-arg-count)
   (if (closure? *val*)
@@ -89,7 +116,7 @@
                 ;(write-string "no interrupt is pending" (current-error-port))
                 (loop (s48-jump-native return-address template))))))
       ((3)
-       (goto return-values s48-*native-protocol* null 0))
+       (error "unexpected native return value" tag))
       ((4)
        (goto interpret *code-pointer*))
       ((5)
@@ -375,7 +402,7 @@
     (let loop ((protocol (code-vector-ref code 1))
   	       (stack-space default-stack-space)
   	       (native? #f))
-      (let ((win (lambda (skip stack-arg-count)
+      (let ((win (lambda (skip)
   		   (if native?
   		       (goto call-native-code skip stack-space)
 		       (let ((template (closure-template *val*)))
@@ -390,7 +417,7 @@
 				       (begin
 					 (push-list list-args list-arg-count)
 					 (unspecific))) ; avoid type problem
-				   (win skip total-arg-count))
+				   (win skip))
 				 (lose))))
 	      ;; N-ary procedure.
 	      (n-ary-match (lambda (wants-stack-args skip)
@@ -400,7 +427,7 @@
 						       stack-arg-count
 						       list-args
 						       list-arg-count)
-				   (win skip (+ wants-stack-args 1)))
+				   (win skip))
 				 (lose))))
 	      ;; If there are > 2 args the top two are pushed on the stack.
 	      ;; Then the remaining list, the total number of arguments, and
@@ -417,7 +444,7 @@
 							list-arg-count)
 				    (push (enter-fixnum final-stack-arg-count))
 				    (push (enter-fixnum total-arg-count))
-				    (win skip (+ final-stack-arg-count 3))))))
+				    (win skip)))))
 	  (cond ((= protocol nary-dispatch-protocol)
 		 (cond ((< total-arg-count 3)
 			(let ((skip (code-vector-ref code (+ 3 total-arg-count))))
