@@ -1,5 +1,7 @@
 ; -*- Mode: Scheme; Syntax: Scheme; Package: Scheme; -*-
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Mike Sperber, Martin Gasbichler
 
 ;Need to fix the byte-code compiler to make jump etc. offsets from the
 ;beginning of the instruction.  (Later: why?)
@@ -59,6 +61,10 @@
 (define (set-current-proposal! proposal)
   (record-set! (current-thread) 3 proposal))
 
+; For saving native code registers accross a GC
+
+(define s48-*nc-template*)
+
 ;----------------
 
 (define (clear-registers)
@@ -82,6 +88,7 @@
   (set! *os-signal-ring-ready* 0)
   (set! *os-signal-ring-end* 0)
   (set! *interrupted-template* false)
+  (set! s48-*nc-template* false)
   unspecific-value)
 
 (define (s48-initialize-shared-registers! s-d e-h i-h f-a)
@@ -113,6 +120,7 @@
     (set! *call-with-values-return-code*
 	  (s48-trace-value *call-with-values-return-code*))
     (set! *interrupted-template*  (s48-trace-value *interrupted-template*))
+    (set! s48-*nc-template*       (s48-trace-value s48-*nc-template*))
 
     (shared-set! *session-data*
 		 (s48-trace-value (shared-ref *session-data*)))
@@ -133,6 +141,7 @@
     (set-code-pointer! *last-code-called* *saved-pc*)
     (set! *last-code-pointer-resumed* *code-pointer*)
     (partition-finalizer-alist!)
+    (trace-channel-names s48-trace-value)
     (close-untraced-channels! s48-extant? s48-trace-value)
     (set! *gc-in-trouble?* in-trouble?)
     (note-interrupt! (if major?
@@ -441,16 +450,24 @@
 				       code
 				       (enter-fixnum exception)
 				       (enter-fixnum instruction-size)))
-      (begin
+      (receive (bc-code bc-pc) (current-code+pc)
 	(push *native-exception-cont*)
 	(set-cont-to-stack!)
 	(write-string "handling exception for nc " (current-error-port))
 	(write-integer *native-exception-cont* (current-error-port))
+	(write-string "return code pc is " (current-error-port))
+	(write-integer return-code-pc (current-error-port))
+        (write-string " opcode is " (current-error-port))
+        (write-integer (current-opcode) (current-error-port))
+        (write-string " exception is " (current-error-port))
+        (write-integer exception (current-error-port))
+        (write-string " *val* is " (current-error-port))
+        (write-integer *val* (current-error-port))
 	(push-native-exception-continuation! (code+pc->code-pointer *native-exception-return-code*
 								    return-code-pc)
-					     (enter-fixnum (current-opcode))
-					     *native-exception-cont*
-					     (enter-fixnum exception))
+					     (enter-fixnum exception)
+                                             (enter-fixnum bc-pc)
+                                             bc-code)
 	(reset-native-exception-cont!)))
   (push (enter-fixnum (current-opcode)))
   (push (enter-fixnum exception)))
@@ -468,15 +485,16 @@
 	     (raise-exception illegal-exception-return 0 exception))))))
 
 (define-opcode return-from-native-exception
-  (receive (opcode code exception ignore)
-      (pop-exception-data)
-    (let ((opcode (extract-fixnum opcode)))
+  (receive (exception bc-pc bc-code)
+      (pop-native-exception-data)
+    (let* ((bc-pc (extract-fixnum bc-pc))
+           (opcode (code-vector-ref bc-code bc-pc)))
       (cond ((okay-to-proceed? opcode)
 	     (write-string "returning to nc " (current-error-port))
 	     (write-integer (fetch *stack*)  (current-error-port))
 	     (return-values 0 null 0))
 	    (else 
-	     (set-code-pointer! code 0) ; Uahh...
+	     (set-code-pointer! bc-code bc-pc)
 	     (raise-exception illegal-exception-return 0 exception))))))
 
 ; It's okay to proceed if the opcode is a data operation, which are all those
@@ -484,7 +502,8 @@
 
 (define (okay-to-proceed? opcode)
   (or (<= (enum op eq?) opcode)
-      (= opcode (enum op global))))
+      (= opcode (enum op global))
+      (= opcode (enum op set-global!))))
 	      
 (define no-exceptions? #f)
 
@@ -812,6 +831,12 @@
 	(else
 	 (goto continue 2))))
 
+; Peephole instruction for the sake of the native code. As the
+; operands are the original instructions, we here may simple execute
+; them.
+(define-opcode test-op+jump-if-false
+  (goto continue 2))
+
 ; Unconditional jumps
 
 (define-opcode jump
