@@ -1,4 +1,7 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Marcus Crestani, Mike Sperber,
+; Martin Gasbichler
 
 
 (define-structures ((vm-utilities vm-utilities-interface))
@@ -18,6 +21,9 @@
     (define external-call
       (external "s48_external_call" (=> (integer integer integer address)
 					integer)))
+    (define external-call-2
+      (external "s48_external_call_2" (=> (integer integer integer address)
+					integer)))
     (define schedule-interrupt 
       (external "s48_schedule_alarm_interrupt" (=> (integer) integer)))
 
@@ -64,13 +70,13 @@
     ; for use in C functions usable from external code, defined as
     ; PreScheme procedures
 
-    (define raise-argument-type-error
+    (define argument-type-violation
       ;; value
-      (external "s48_raise_argument_type_error" (=> (integer) null)))
+      (external "s48_argument_type_violation" (=> (integer) null)))
 
-    (define raise-range-error
+    (define range-violation
       ;; value, min, max
-      (external "s48_raise_range_error" (=> (integer integer integer) null)))
+      (external "s48_range_violation" (=> (integer integer integer) null)))
 
     ; Lots of bignum stuff.  This should be moved to its own interface.
     (define export-key
@@ -125,6 +131,10 @@
     (define external-bignum-fits-in-word?
       (external "s48_bignum_fits_in_word_p" (=> (address integer boolean) 
  						boolean)))
+
+    ;; external call interface
+    (define trace-external-calls
+      (external "s48_trace_external_calls" (=> () null)))
     ))
 
 (define-structures ((channel-io channel-interface)
