@@ -1,8 +1,17 @@
-; Copyright (c) 1993-2008 by Richard Kelsey and Jonathan Rees. See file COPYING.
+; Part of Scheme 48 1.9.  See file COPYING for notices and license.
+
+; Authors: Richard Kelsey, Jonathan Rees, Marcus Crestani, Mike Sperber,
+; Martin Gasbichler
 
 
 (define-structure vm-utilities vm-utilities-interface
-  (open scheme prescheme)
+  (open scheme
+	(subset prescheme
+		(char->ascii
+		 error
+		 enum errors
+		 shift-left bitwise-and arithmetic-shift-right logical-shift-right 
+		 write-string write-integer current-error-port)))
   (files (util vm-utilities))
   (begin
 ;    (define-syntax assert
@@ -15,7 +24,7 @@
 
 (define-structure external external-interface
   (open scheme bitwise ps-memory)
-  (for-syntax (open scheme signals)) ; for error
+  (for-syntax (open scheme)) ; for error
   (files (util external)))
 
 (define-structures ((channel-io channel-interface)
